/*--------------------------------------------------------------------------------------------
*
*	Header pro upgrade button
*
*--------------------------------------------------------------------------------------------*/
.acf-admin-toolbar {

	a.acf-admin-toolbar-upgrade-btn {
		display: inline-flex;
		align-items: center;
		align-self: stretch;
		padding: {
			top: 0;
			right: 16px;
			bottom: 0;
			left: 16px;
		};
		background: $gradient-pro;
		box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.16);
		border-radius: $radius-md;
		text-decoration: none;

		@media screen and (max-width: 768px) {
			display: none;
		}

		&:focus {
			border: none;
			outline: none;
			box-shadow: none;
		}

		p {
			margin: 0;
			padding: {
				top: 8px;
				bottom: 8px;
			}

			@extend .p4;
			font-weight: 400;
			text-transform: none;
			color: #fff;
		}

		.acf-icon {
			$icon-size: 18px;
			width: $icon-size;
			height: $icon-size;
			margin: {
				right: 6px;
				left: -2px;
			};
			background-color: $gray-50;
		}

	}

}
