/*---------------------------------------------------------------------------------------------
*
*	Flexible Content
*
*---------------------------------------------------------------------------------------------*/

.acf-field-setting-fc_layout {
	.acf-toggle-fc-layout {
		width: 34px;
		height: 31px;
		margin: 0;
		padding: 0;
		border: 0;
		background: transparent;
		cursor: pointer;
		left: 20.83%;
		right: 20.83%;
		top: 33.33%;
		bottom: 33.33%;
	}

	.toggle-indicator::before {
		z-index:-1;
		content: "";
		display: inline-flex;
		width: 20px;
		height: 20px;
		margin-left: -28px;
		background-color: currentColor;
		border: none;
		border-radius: 0;
		-webkit-mask-size: contain;
		mask-size: contain;
		-webkit-mask-repeat: no-repeat;
		mask-repeat: no-repeat;
		-webkit-mask-position: center;
		mask-position: center;
		-webkit-mask-image: url(../../../images/icons/icon-chevron-down.svg);
		mask-image: url(../../../images/icons/icon-chevron-down.svg);

		@at-root .rtl #{&} {
			margin-left: 0px;
			position: absolute;
			top: 9px;
			z-index: 100;
			left: 8px;
		}

	}

	.toggle-indicator.open::before{
		-webkit-mask-image: url(../../../images/icons/icon-chevron-up.svg);
		mask-image: url(../../../images/icons/icon-chevron-up.svg);
	}

	.toggle-indicator.closed::before{
		-webkit-mask-image: url(../../../images/icons/icon-chevron-down.svg);
		mask-image: url(../../../images/icons/icon-chevron-down.svg);
	}

	// name label
	.acf-flexible-content-field-label-name {
		padding-left: 5px;
	}

	// meta
	.acf-fc-meta {
		margin: 0 0 10px;
		padding: 0;

		li {
			margin: 0 0 10px;
			padding: 0;
		}

		.acf-fc-meta-display {
			float: left;
			width: 100%;
			padding-right: 5px;
		}

		.acf-fc-meta-left {
			width: calc(50% - 4px);
			float: left;
			clear: left;
			margin: {
				right: 4px;
			};
		}

		.acf-fc-meta-right {
			width: calc(50% - 4px);
			float: left;
			margin: {
				left: 4px;
			};
		}

		.acf-fc-meta-min {
			width: calc(25% - 5px);
			float: left;
			margin: {
				right: 5px;
			};
		}

		.acf-fc-meta-max {
			width: calc(25% - 10px);
			float: left;
			margin: {
				left: 4px;
			};
		}

		.acf-fc-meta-label .acf-input-prepend,
		.acf-fc-meta-name .acf-input-prepend,
		.acf-fc-meta-display .acf-input-prepend {
			min-width: 60px;
		}
	}

	.acf-fc_draggable,
	.reorder-layout {
		cursor: grab;
	}

	// actions
	.acf-fl-actions {
		// visibility: hidden;

		a {
			padding: 1px 0;
			font-size: 13px;
			line-height: 20px;
		}
	}
}


/*---------------------------------------------------------------------------------------------
*
*	Clone
*
*---------------------------------------------------------------------------------------------*/

.acf-field-object-clone {

	/* group */
	&[data-display="group"] {


	}


	/* seamless */
	&[data-display="seamless"] {

		.acf-field-setting-instructions,
		.acf-field-setting-layout,
		.acf-field-setting-wrapper,
		.acf-field-setting-conditional_logic {
			display: none;
		}

	}

}
