[data-acf-inline-contenteditable="1"][contenteditable=true]:empty::before {
    content: attr(data-acf-placeholder);
    opacity: .62;
}

[data-acf-inline-contenteditable="1"][contenteditable=true]:empty {
    border: 1px dashed rgba(255, 0, 0, 0);
}

[data-acf-inline-fields-uid]:hover,
[data-acf-inline-contenteditable]:hover {
    outline: 2px solid var(--wp-admin-theme-color);
    outline-offset: 2px;
}

.acf-block-has-validation-error {
    border: 2px solid #d94f4f;
}