<?php
return ['domain'=>NULL,'plural-forms'=>NULL,'language'=>'','project-id-version'=>'','pot-creation-date'=>'2025-01-08T19:43:20+00:00','po-revision-date'=>'2025-01-08T19:43:20+00:00','messages'=>['Block type name is required.'=>'ערך %s נדרש','%s settings'=>'הגדרות','Options'=>'אפשרויות','Update'=>'עדכון','Options Updated'=>'האפשרויות עודכנו','Publish'=>'פורסם','No Custom Field Groups found for this options page. <a href="%s">Create a Custom Field Group</a>'=>'אף קבוצת שדות לא נמצאה בפח. <a href="%s">יצירת קבוצת שדות מיוחדים</a>','Fields'=>'שדות','Display'=>'תצוגה','Layout'=>'פריסת תוכן','Block'=>'בלוק','Table'=>'טבלה','Row'=>'שורה','(no title)'=>'(אין כותרת)','Flexible Content'=>'תוכן גמיש','Add Row'=>'הוספת שורה חדשה','layout'=>'פריסה' . "\0" . 'פריסה','layouts'=>'פריסות','This field requires at least {min} {label} {identifier}'=>'שדה זה דורש לפחות {min} {label} {identifier}','This field has a limit of {max} {label} {identifier}'=>'לשדה זה יש מגבלה של  {max} {identifier}','{available} {label} {identifier} available (max {max})'=>'‏{available} {label} {identifier} זמינים (מקסימום {max})','{required} {label} {identifier} required (min {min})'=>'‏{required} {label} {identifier} נדרש (מינימום {min})','Flexible Content requires at least 1 layout'=>'דרושה לפחות פריסה אחת לתוכן הגמיש','Click the "%s" button below to start creating your layout'=>'לחצו על כפתור "%s" שלמטה כדי להתחיל ביצירת הפריסה','Drag to reorder'=>'גרור ושחרר לסידור מחדש','Add layout'=>'הוספת פריסה','Duplicate layout'=>'שכפול פריסת תוכן','Remove layout'=>'הסרת פריסה','Delete Layout'=>'מחיקת פריסת תוכן','Duplicate Layout'=>'שכפול פריסת תוכן','Add New Layout'=>'הוספת פריסת תוכן חדשה','Add Layout'=>'הוספת פריסה','Label'=>'תווית','Name'=>'שם','Min'=>'מינימום','Max'=>'מקסימום','Minimum Layouts'=>'מינימום פריסות','Maximum Layouts'=>'מקסימום פריסות','Button Label'=>'תווית כפתור','Gallery'=>'גלריה','Add Image to Gallery'=>'הוספת תמונה לגלריה','Maximum selection reached'=>'הגעתם למקסימום בחירה','Length'=>'אורך','Edit'=>'עריכה','Remove'=>'הסר','Title'=>'כותרת','Description'=>'תיאור','Add to gallery'=>'הוספה לגלריה','Bulk actions'=>'עריכה קבוצתית','Sort by date uploaded'=>'מיון לפי תאריך העלאה','Sort by date modified'=>'מיון לפי תאריך שינוי','Sort by title'=>'מיון לפי כותרת','Reverse current order'=>'הפוך סדר נוכחי','Close'=>'סגור','Return Format'=>'פורמט חוזר','Image Array'=>'מערך תמונות','Image URL'=>'כתובת אינטרנט של התמונה','Image ID'=>'מזהה ייחודי של תמונה','Library'=>'ספריה','Limit the media library choice'=>'הגבלת אפשרויות ספריית המדיה','All'=>'הכל','Uploaded to post'=>'הועלה לפוסט','Minimum Selection'=>'מינימום בחירה','Maximum Selection'=>'מקסימום בחירה','Height'=>'גובה','Preview Size'=>'גודל תצוגה','%1$s requires at least %2$s selection'=>'%s מחייב לפחות בחירה %s' . "\0" . '%s מחייב לפחות בחירה %s','Repeater'=>'שדה חזרה','Minimum rows not reached ({min} rows)'=>'הגעתם למינימום שורות האפשרי ({min} שורות)','Maximum rows reached ({max} rows)'=>'הגעתם למקסימום שורות האפשרי ({max} שורות)','Error loading page'=>'שגיאה בבקשת האימות','Sub Fields'=>'שדות משנה','Pagination'=>'מיקום','Rows Per Page'=>'עמוד פוסטים','Minimum Rows'=>'מינימום שורות','Maximum Rows'=>'מקסימום שורות','Click to reorder'=>'גרור ושחרר לסידור מחדש','Add row'=>'הוספת שורה','Duplicate row'=>'שיכפול','Remove row'=>'הסרת שורה','Current Page'=>'עמוד ראשי','First Page'=>'עמוד ראשי','Previous Page'=>'עמוד פוסטים','Next Page'=>'עמוד ראשי','Last Page'=>'עמוד פוסטים','No block types exist'=>'לא קיים דף אפשרויות','Options Page'=>'עמוד אפשרויות','No'=>'לא','Yes'=>'כן']];