<?php
return ['domain'=>NULL,'plural-forms'=>NULL,'language'=>'','project-id-version'=>'','pot-creation-date'=>'2025-01-08T19:43:19+00:00','po-revision-date'=>'2025-01-08T19:43:19+00:00','messages'=>['Block type name is required.'=>'%s kitöltése kötelező','%s settings'=>'Új beállítások','Options'=>'Beállítások','Update'=>'Frissítés','Options Updated'=>'Beállítások elmentve','Publish'=>'Közzététel','No Custom Field Groups found for this options page. <a href="%s">Create a Custom Field Group</a>'=>'Nincsenek mezőcsoportok ehhez a beállítás oldalhoz. <a href="%s">Mezőcsoport hozzáadása</a>','Fields'=>'Mezők','Display'=>'Megjelenítés','Layout'=>'Tartalom elrendezés','Block'=>'Blokk','Table'=>'Táblázat','Row'=>'Sorok','Labels will be displayed as %s'=>'A kiválasztott elemek jelennek meg az eredményekben','Prefix Field Labels'=>'Mezőfelirat','Prefix Field Names'=>'Mezőnév','Unknown field'=>'Mezők alatt','(no title)'=>'Rendezés cím szerint','Unknown field group'=>'Mezőcsoport megjelenítése, ha','Flexible Content'=>'Rugalmas tartalom (flexible content)','Add Row'=>'Sor hozzáadása','layout'=>'elrendezés' . "\0" . 'elrendezés','layouts'=>'elrendezés','This field requires at least {min} {label} {identifier}'=>'Ennél a mezőnél legalább {min} {label} {identifier} hozzáadása szükséges','This field has a limit of {max} {label} {identifier}'=>'Ennél a mezőnél legfeljebb {max} {identifier} adható hozzá.','{available} {label} {identifier} available (max {max})'=>'{available} {label} {identifier} adható még hozzá (maximum {max})','{required} {label} {identifier} required (min {min})'=>'{required} {label} {identifier} hozzáadása szükséges (minimum {min})','Flexible Content requires at least 1 layout'=>'Rugalmas tartalomnál legalább egy elrendezést definiálni kell.','Click the "%s" button below to start creating your layout'=>'Kattintsunk lent a "%s" gombra egyéni tartalom létrehozásához.','Drag to reorder'=>'Átrendezéshez húzzuk a megfelelő helyre','Add layout'=>'Elrendezés hozzáadása','Duplicate layout'=>'Elrendezés duplikálása','Remove layout'=>'Elrendezés eltávolítása','Delete Layout'=>'Elrendezés törlése','Duplicate Layout'=>'Elrendezés duplikálása','Add New Layout'=>'Új elrendezés hozzáadása','Add Layout'=>'Elrendezés hozzáadása','Label'=>'Felirat','Name'=>'Név','Min'=>'Minimum','Max'=>'Maximum','Minimum Layouts'=>'Tartalmak minimális száma','Maximum Layouts'=>'Tartalmak maximális száma','Button Label'=>'Gomb felirata','Gallery'=>'Galéria','Add Image to Gallery'=>'Kép hozzáadása a galériához','Maximum selection reached'=>'Elértük a kiválasztható elemek maximális számát','Edit'=>'Szerkesztés','Title'=>'Cím','Caption'=>'Beállítások','Alt Text'=>'Szöveg (text)','Add to gallery'=>'Hozzáadás galériához','Bulk actions'=>'Csoportművelet','Sort by date uploaded'=>'Rendezés feltöltési dátum szerint','Sort by date modified'=>'Rendezés módosítási dátum szerint','Sort by title'=>'Rendezés cím szerint','Reverse current order'=>'Fordított sorrend','Close'=>'Bezárás','Return Format'=>'Visszaadott formátum','Image Array'=>'Kép adattömb (array)','Image URL'=>'Kép URL','Image ID'=>'Kép azonosító','Library'=>'Médiatár','Limit the media library choice'=>'Kiválasztható médiatár elemek korlátozása','All'=>'Összes','Uploaded to post'=>'Feltöltve a bejegyzéshez','Minimum Selection'=>'Minimális választás','Maximum Selection'=>'Maximális választás','Height'=>'Magasság','Append to the end'=>'Beviteli mező után jelenik meg','Preview Size'=>'Előnézeti méret','%1$s requires at least %2$s selection'=>'%s mező esetében legalább %s értéket ki kell választani' . "\0" . '%s mező esetében legalább %s értéket ki kell választani','Repeater'=>'Ismétlő csoportmező (repeater)','Minimum rows not reached ({min} rows)'=>'Nem érjük el a sorok minimális számát (legalább {min} sort hozzá kell adni)','Maximum rows reached ({max} rows)'=>'Elértük a sorok maximális számát (legfeljebb {max} sor adható hozzá)','Sub Fields'=>'Almezők','Pagination'=>'Pozíció','Rows Per Page'=>'Bejegyzések oldala','Minimum Rows'=>'Sorok minimális száma','Maximum Rows'=>'Sorok maximális száma','Collapsed'=>'Részletek bezárása','Click to reorder'=>'Átrendezéshez húzzuk a megfelelő helyre','Add row'=>'Sor hozzáadása','Duplicate row'=>'Duplikálás','Remove row'=>'Sor eltávolítása','Current Page'=>'Kezdőoldal','First Page'=>'Kezdőoldal','Previous Page'=>'Bejegyzések oldala','Next Page'=>'Kezdőoldal','Last Page'=>'Bejegyzések oldala','No block types exist'=>'Nincsenek beállítás oldalak','Options Page'=>'Beállítások oldal','No'=>'Nem','Yes'=>'Igen']];