<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'JsonSchema\\Constraints\\BaseConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/BaseConstraint.php',
    'JsonSchema\\Constraints\\CollectionConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/CollectionConstraint.php',
    'JsonSchema\\Constraints\\Constraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Constraint.php',
    'JsonSchema\\Constraints\\ConstraintInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ConstraintInterface.php',
    'JsonSchema\\Constraints\\EnumConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/EnumConstraint.php',
    'JsonSchema\\Constraints\\Factory' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Factory.php',
    'JsonSchema\\Constraints\\FormatConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/FormatConstraint.php',
    'JsonSchema\\Constraints\\NumberConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/NumberConstraint.php',
    'JsonSchema\\Constraints\\ObjectConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ObjectConstraint.php',
    'JsonSchema\\Constraints\\SchemaConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/SchemaConstraint.php',
    'JsonSchema\\Constraints\\StringConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/StringConstraint.php',
    'JsonSchema\\Constraints\\TypeCheck\\LooseTypeCheck' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/LooseTypeCheck.php',
    'JsonSchema\\Constraints\\TypeCheck\\StrictTypeCheck' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/StrictTypeCheck.php',
    'JsonSchema\\Constraints\\TypeCheck\\TypeCheckInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/TypeCheckInterface.php',
    'JsonSchema\\Constraints\\TypeConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeConstraint.php',
    'JsonSchema\\Constraints\\UndefinedConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/UndefinedConstraint.php',
    'JsonSchema\\Entity\\JsonPointer' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Entity/JsonPointer.php',
    'JsonSchema\\Exception\\ExceptionInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ExceptionInterface.php',
    'JsonSchema\\Exception\\InvalidArgumentException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidArgumentException.php',
    'JsonSchema\\Exception\\InvalidConfigException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidConfigException.php',
    'JsonSchema\\Exception\\InvalidSchemaException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaException.php',
    'JsonSchema\\Exception\\InvalidSchemaMediaTypeException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaMediaTypeException.php',
    'JsonSchema\\Exception\\InvalidSourceUriException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSourceUriException.php',
    'JsonSchema\\Exception\\JsonDecodingException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/JsonDecodingException.php',
    'JsonSchema\\Exception\\ResourceNotFoundException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ResourceNotFoundException.php',
    'JsonSchema\\Exception\\RuntimeException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/RuntimeException.php',
    'JsonSchema\\Exception\\UnresolvableJsonPointerException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/UnresolvableJsonPointerException.php',
    'JsonSchema\\Exception\\UriResolverException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/UriResolverException.php',
    'JsonSchema\\Exception\\ValidationException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ValidationException.php',
    'JsonSchema\\Iterator\\ObjectIterator' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Iterator/ObjectIterator.php',
    'JsonSchema\\Rfc3339' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Rfc3339.php',
    'JsonSchema\\SchemaStorage' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorage.php',
    'JsonSchema\\SchemaStorageInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorageInterface.php',
    'JsonSchema\\UriResolverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/UriResolverInterface.php',
    'JsonSchema\\UriRetrieverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/UriRetrieverInterface.php',
    'JsonSchema\\Uri\\Retrievers\\AbstractRetriever' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/AbstractRetriever.php',
    'JsonSchema\\Uri\\Retrievers\\Curl' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/Curl.php',
    'JsonSchema\\Uri\\Retrievers\\FileGetContents' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/FileGetContents.php',
    'JsonSchema\\Uri\\Retrievers\\PredefinedArray' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/PredefinedArray.php',
    'JsonSchema\\Uri\\Retrievers\\UriRetrieverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/UriRetrieverInterface.php',
    'JsonSchema\\Uri\\UriResolver' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriResolver.php',
    'JsonSchema\\Uri\\UriRetriever' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriRetriever.php',
    'JsonSchema\\Validator' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Validator.php',
    'SCF\\AI\\AI' => $baseDir . '/src/AI/AI.php',
    'SCF\\AI\\Abilities\\Abilities' => $baseDir . '/src/AI/Abilities/Abilities.php',
    'SCF\\AI\\Abilities\\AbstractAbilityGroup' => $baseDir . '/src/AI/Abilities/AbstractAbilityGroup.php',
    'SCF\\AI\\Abilities\\FieldGroup' => $baseDir . '/src/AI/Abilities/FieldGroup.php',
    'SCF\\AI\\Abilities\\PostType' => $baseDir . '/src/AI/Abilities/PostType.php',
    'SCF\\AI\\Abilities\\SCF_REST_Ability' => $baseDir . '/src/AI/Abilities/SCF_REST_Ability.php',
    'SCF\\AI\\Abilities\\Taxonomy' => $baseDir . '/src/AI/Abilities/Taxonomy.php',
    'SCF\\AI\\GEO\\FieldSettings' => $baseDir . '/src/AI/GEO/FieldSettings.php',
    'SCF\\AI\\GEO\\GEO' => $baseDir . '/src/AI/GEO/GEO.php',
    'SCF\\AI\\GEO\\Outputs\\Blocks' => $baseDir . '/src/AI/GEO/Outputs/Blocks.php',
    'SCF\\AI\\GEO\\Outputs\\Posts' => $baseDir . '/src/AI/GEO/Outputs/Posts.php',
    'SCF\\AI\\GEO\\Schema' => $baseDir . '/src/AI/GEO/Schema.php',
    'SCF\\AI\\GEO\\SchemaData' => $baseDir . '/src/AI/GEO/SchemaData.php',
    'SCF\\Blocks\\Bindings' => $baseDir . '/includes/Blocks/Bindings.php',
    'SCF\\Blocks\\Bindings_Editor' => $baseDir . '/includes/Blocks/Bindings_Editor.php',
    'SCF\\CLI\\CLI' => $baseDir . '/src/CLI/CLI.php',
    'SCF\\CLI\\JsonCommand' => $baseDir . '/src/CLI/JsonCommand.php',
    'SCF\\Datastore\\Check_Screen' => $baseDir . '/includes/Datastore/Check_Screen.php',
    'SCF\\Datastore\\Localization' => $baseDir . '/includes/Datastore/Localization.php',
    'SCF\\Datastore\\REST_Save' => $baseDir . '/includes/Datastore/REST_Save.php',
    'SCF\\Datastore\\Revisions' => $baseDir . '/includes/Datastore/Revisions.php',
    'SCF\\Fields\\FlexibleContent\\Layout' => $baseDir . '/includes/fields/FlexibleContent/Layout.php',
    'SCF\\Fields\\FlexibleContent\\Render' => $baseDir . '/includes/fields/FlexibleContent/Render.php',
    'SCF\\Forms\\WC_Order' => $baseDir . '/includes/forms/WC_Order.php',
    'SCF\\Meta\\Comment' => $baseDir . '/includes/Meta/Comment.php',
    'SCF\\Meta\\MetaLocation' => $baseDir . '/includes/Meta/MetaLocation.php',
    'SCF\\Meta\\Option' => $baseDir . '/includes/Meta/Option.php',
    'SCF\\Meta\\Post' => $baseDir . '/includes/Meta/Post.php',
    'SCF\\Meta\\Term' => $baseDir . '/includes/Meta/Term.php',
    'SCF\\Meta\\User' => $baseDir . '/includes/Meta/User.php',
    'SCF\\Meta\\WooOrder' => $baseDir . '/includes/Meta/WooOrder.php',
    'SCF\\Site_Health\\AI_Usage' => $baseDir . '/src/Site_Health/AI_Usage.php',
    'SCF\\Site_Health\\Site_Health' => $baseDir . '/src/Site_Health/Site_Health.php',
);
