<?php
return ['domain'=>NULL,'plural-forms'=>NULL,'language'=>'','project-id-version'=>'','pot-creation-date'=>'2025-01-08T19:43:19+00:00','po-revision-date'=>'2025-01-08T19:43:19+00:00','messages'=>['Block type name is required.'=>'%s 值為必填','Switch to Edit'=>'切換至編輯','Switch to Preview'=>'切換至預覽','%s settings'=>'設定','Options'=>'選項','Update'=>'更新','Options Updated'=>'選項已更新','Publish'=>'發佈','No Custom Field Groups found for this options page. <a href="%s">Create a Custom Field Group</a>'=>'此設定頁沒有自訂欄位群組。<a href="%s">建立一個自訂欄位群組</a>','Edit field group'=>'編輯欄位群組','nounClone'=>'分身','Fields'=>'欄位','Select one or more fields you wish to clone'=>'選取一或多個你希望複製的欄位','Display'=>'顯示','Specify the style used to render the clone field'=>'指定繪製分身欄位的樣式','Group (displays selected fields in a group within this field)'=>'群組（顯示該欄位內群組中被選定的欄位）','Seamless (replaces this field with selected fields)'=>'無縫（用選定欄位取代此欄位）','Layout'=>'版面配置','Specify the style used to render the selected fields'=>'指定用於呈現選定欄位的樣式','Block'=>'區塊','Table'=>'表格','Row'=>'行','Labels will be displayed as %s'=>'標籤將顯示為%s','Prefix Field Labels'=>'前置欄位標籤','Values will be saved as %s'=>'值將被儲存為 %s','Prefix Field Names'=>'前置欄位名稱','Unknown field'=>'未知的欄位','(no title)'=>'(無標題)','Unknown field group'=>'未知的欄位群組','All fields from %s field group'=>'所有欄位來自 %s 欄位群組','Flexible Content'=>'彈性內容','Add Row'=>'新增列','layout'=>'版面配置','layouts'=>'版面','This field requires at least {min} {label} {identifier}'=>'這個欄位至少需要 {min} {label} {identifier}','This field has a limit of {max} {label} {identifier}'=>'此欄位的限制為 {max} {label} {identifier}','{available} {label} {identifier} available (max {max})'=>'{available} {label} {identifier} 可用 (最大 {max})','{required} {label} {identifier} required (min {min})'=>'{required} {label} {identifier} 需要 (最小 {min})','Flexible Content requires at least 1 layout'=>'彈性內容需要至少 1 個版面配置','Click the "%s" button below to start creating your layout'=>'點擊下方的 "%s" 按鈕以新增設定','Drag to reorder'=>'拖曳排序','Add layout'=>'新增版面','Duplicate layout'=>'複製版面','Remove layout'=>'移除版面','Click to toggle'=>'點擊切換','Delete Layout'=>'刪除版面','Duplicate Layout'=>'複製版面','Add New Layout'=>'新增版面','Add Layout'=>'新增版面','Label'=>'標籤','Name'=>'名稱','Min'=>'最小','Max'=>'最大','Minimum Layouts'=>'最少可使用版面數量','Maximum Layouts'=>'最多可使用版面數量','Button Label'=>'按鈕標籤','Gallery'=>'圖庫','Add Image to Gallery'=>'新增圖片到圖庫','Maximum selection reached'=>'已達到最大選擇','Length'=>'長度','Edit'=>'編輯','Remove'=>'刪除','Title'=>'標題','Caption'=>'標題','Alt Text'=>'替代文字','Description'=>'描述','Add to gallery'=>'加入圖庫','Bulk actions'=>'批次操作','Sort by date uploaded'=>'依上傳日期排序','Sort by date modified'=>'依修改日期排序','Sort by title'=>'依標題排序','Reverse current order'=>'反向目前順序','Close'=>'關閉','Return Format'=>'回傳格式','Image Array'=>'圖片陣列','Image URL'=>'圖片網址','Image ID'=>'圖片ID','Library'=>'媒體庫','Limit the media library choice'=>'限制媒體庫選擇','All'=>'所有','Uploaded to post'=>'已上傳至文章','Minimum Selection'=>'最小選擇','Maximum Selection'=>'最大選擇','Minimum'=>'最小','Restrict which images can be uploaded'=>'限制哪些圖片可以上傳','Width'=>'寬','Height'=>'高','File size'=>'檔案容量','Maximum'=>'最大','Comma separated list. Leave blank for all types'=>'請以逗號分隔列出。留白表示允許所有類型','Insert'=>'插入','Specify where new attachments are added'=>'指定新附件加入的位置','Append to the end'=>'附加在後','Prepend to the beginning'=>'插入至最前','Preview Size'=>'預覽圖大小','%1$s requires at least %2$s selection'=>'%s 需要至少 %s 選擇','Repeater'=>'重複器','Minimum rows not reached ({min} rows)'=>'已達最小行數 ( {min} 行 )','Maximum rows reached ({max} rows)'=>'已達最大行數 ( {max} 行 )','Sub Fields'=>'子欄位','Pagination'=>'欄位群組位置','Rows Per Page'=>'文章頁面','Set the number of rows to be displayed on a page.'=>'選擇要顯示的分類法','Minimum Rows'=>'最小行數','Maximum Rows'=>'最大行數','Collapsed'=>'收合','Select a sub field to show when row is collapsed'=>'選取一個子欄位，讓它在行列收合時顯示','Click to reorder'=>'拖曳排序','Add row'=>'新增列','Duplicate row'=>'複製','Remove row'=>'移除列','Current Page'=>'目前使用者','First Page'=>'網站首頁','Previous Page'=>'文章頁面','Next Page'=>'網站首頁','Last Page'=>'文章頁面','No block types exist'=>'設定頁面不存在','Options Page'=>'設定頁面','No'=>'否','Yes'=>'是']];