<?php
return ['domain'=>NULL,'plural-forms'=>NULL,'language'=>'','project-id-version'=>'','pot-creation-date'=>'2025-01-08T19:43:20+00:00','po-revision-date'=>'2025-01-08T19:43:20+00:00','messages'=>['Block type name is required.'=>'vyžaduje sa hodnota %s','%s settings'=>'Nové nastavenia','Options'=>'Nastavenia ','Update'=>'Aktualizovať ','Options Updated'=>'Nastavenia aktualizované','Publish'=>'Publikovať ','No Custom Field Groups found for this options page. <a href="%s">Create a Custom Field Group</a>'=>'Pre túto stránku neboli nájdené žiadne vlastné skupiny polí. <a href="%s">Vytvoriť novú vlastnú skupinu polí</a>','Edit field group'=>'Upraviť skupinu polí ','Fields'=>'Polia ','Display'=>'Zobrazenie','Layout'=>'Rozmiestnenie','Block'=>'Blok','Table'=>'Tabuľka','Row'=>'Riadok','Labels will be displayed as %s'=>'Vybraté prvky budú zobrazené v každom výsledku ','Prefix Field Labels'=>'Označenie poľa ','Prefix Field Names'=>'Meno poľa ','Unknown field'=>'Pod poliami','(no title)'=>'(bez názvu)','Unknown field group'=>'Zobraziť túto skupinu poľa, ak','Flexible Content'=>'Flexibilný obsah ','Add Row'=>'Pridať riadok','layout'=>'rozloženie' . "\0" . 'rozloženie' . "\0" . 'rozloženie','layouts'=>'rozloženia','This field requires at least {min} {label} {identifier}'=>'Toto pole vyžaduje najmenej {min} {label} {identifier}','This field has a limit of {max} {label} {identifier}'=>'Toto pole vyžaduje najviac {max} {identifier}','{available} {label} {identifier} available (max {max})'=>'{available} {label} {identifier} dostupné (max {max})','{required} {label} {identifier} required (min {min})'=>'{required} {label} {identifier} vyžadované (min {min})','Flexible Content requires at least 1 layout'=>'Flexibilný obsah vyžaduje aspoň jedno rozloženie','Click the "%s" button below to start creating your layout'=>'Pre vytvorenie rozloženia kliknite na tlačidlo "%s"','Drag to reorder'=>'Zmeňte poradie pomocou funkcie ťahaj a pusť','Add layout'=>'Pridať rozloženie','Duplicate layout'=>'Duplikovať rozloženie','Remove layout'=>'Odstrániť rozloženie','Delete Layout'=>'Vymazať rozloženie','Duplicate Layout'=>'Duplikovať rozloženie','Add New Layout'=>'Pridať nové rozloženie','Add Layout'=>'Pridať rozloženie','Label'=>'Označenie ','Name'=>'Meno','Min'=>'Min','Max'=>'Max','Minimum Layouts'=>'Minimálne rozloženie','Maximum Layouts'=>'Maximálne rozloženie','Button Label'=>'Označenie tlačidla','Gallery'=>'Galéria','Add Image to Gallery'=>'Pridať obrázok do galérie','Maximum selection reached'=>'Maximálne dosiahnuté hodnoty','Length'=>'Dĺžka','Edit'=>'Upraviť','Remove'=>'Odstrániť','Title'=>'Názov','Caption'=>'Nastavenia ','Alt Text'=>'Text ','Add to gallery'=>'Pridať do galérie','Bulk actions'=>'Hromadné akcie','Sort by date uploaded'=>'Triediť podľa dátumu nahrania','Sort by date modified'=>'Triediť podľa poslednej úpravy','Sort by title'=>'Triediť podľa názvu','Reverse current order'=>'Zvrátiť aktuálnu objednávku','Close'=>'Zatvoriť ','Return Format'=>'Formát odpovede','Image Array'=>'Obrázok ','Image URL'=>'URL adresa obrázka ','Image ID'=>'ID obrázka ','Library'=>'Knižnica ','Limit the media library choice'=>'Obmedziť výber knižnice médií ','All'=>'Všetky ','Uploaded to post'=>'Nahrané do príspevku ','Minimum Selection'=>'Minimálny výber','Maximum Selection'=>'Maximálny výber','Minimum'=>'Minimálny počet','Restrict which images can be uploaded'=>'Určite, ktoré typy obrázkov môžu byť nahraté','Width'=>'Šírka','Height'=>'Výška ','File size'=>'Veľkosť súboru ','Maximum'=>'Maximálny počet','Comma separated list. Leave blank for all types'=>'Zoznam, oddelený čiarkou. Nechajte prázdne pre všetky typy','Append to the end'=>'Zobrazí sa po vstupe','Preview Size'=>'Veľkosť náhľadu ','%1$s requires at least %2$s selection'=>'%s vyžaduje výber najmenej %s' . "\0" . '%s vyžadujú výber najmenej %s' . "\0" . '%s vyžaduje výbej najmenej %s','Repeater'=>'Opakovač','Minimum rows not reached ({min} rows)'=>'Dosiahnutý počet minimálneho počtu riadkov ({min} rows)','Maximum rows reached ({max} rows)'=>'Maximálny počet riadkov ({max} rows)','Sub Fields'=>'Podpolia','Pagination'=>'Pozícia ','Rows Per Page'=>'Stránka príspevkov ','Minimum Rows'=>'Minimálny počet riadkov','Maximum Rows'=>'Maximálny počet riadkov','Collapsed'=>'Zmenšiť detaily ','Click to reorder'=>'Zmeňte poradie pomocou funkcie ťahaj a pusť','Add row'=>'Pridať riadok','Duplicate row'=>'Duplikovať ','Remove row'=>'Odstrániť riadok','Current Page'=>'Aktuálny používateľ','First Page'=>'Úvodná stránka ','Previous Page'=>'Stránka príspevkov ','Next Page'=>'Úvodná stránka ','Last Page'=>'Stránka príspevkov ','No block types exist'=>'Neexistujú nastavenia stránok','Options Page'=>'Stránka nastavení ','No'=>'Nie','Yes'=>'Áno ']];