<?php return array(
    'root' => array(
        'name' => 'wordpress/secure-custom-fields',
        'pretty_version' => 'dev-trunk',
        'version' => 'dev-trunk',
        'reference' => '7ca085e2fbb494e52ada828852c06b0ef58e1e23',
        'type' => 'wordpress-plugin',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'justinrainbow/json-schema' => array(
            'pretty_version' => '5.3.0',
            'version' => '5.3.0.0',
            'reference' => 'feb2ca6dd1cebdaf1ed60a4c8de2e53ce11c4fd8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../justinrainbow/json-schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wordpress/secure-custom-fields' => array(
            'pretty_version' => 'dev-trunk',
            'version' => 'dev-trunk',
            'reference' => '7ca085e2fbb494e52ada828852c06b0ef58e1e23',
            'type' => 'wordpress-plugin',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
