<?php
/**
 * ACF 6.8.0 feature port.
 *
 * @package wordpress/secure-custom-fields
 */

// phpcs:disable -- Upstream ACF 6.8.0 feature-port files are kept close to source.

/**
 * Schema.org type hierarchy data
 *
 * This file is auto-generated by tools/generate-schema.js
 * DO NOT EDIT MANUALLY - Run 'npm run generate-schema' to regenerate
 *
 * Generated: 2026-02-25
 * Source: https://schema.org/version/latest/schemaorg-current-https.jsonld
 *
 * @package SCF\AI\GEO
 */

return array(
	'Conversation'                          => 'CreativeWork',
	'TheaterEvent'                          => 'Event',
	'WatchAction'                           => 'ConsumeAction',
	'AnalysisNewsArticle'                   => 'NewsArticle',
	'Room'                                  => 'Accommodation',
	'WearableSizeGroupEnumeration'          => 'SizeGroupEnumeration',
	'FoodEstablishment'                     => 'LocalBusiness',
	'CriticReview'                          => 'Review',
	'CompleteDataFeed'                      => 'DataFeed',
	'JewelryStore'                          => 'Store',
	'IPTCDigitalSourceEnumeration'          => 'MediaEnumeration',
	'LeaveAction'                           => 'InteractAction',
	'BoatReservation'                       => 'Reservation',
	'WholesaleStore'                        => 'Store',
	'Diet'                                  => 'CreativeWork',
	'Certification'                         => 'fibo-fnd-arr-doc:Certificate',
	'MedicalRiskFactor'                     => 'MedicalEntity',
	'Continent'                             => 'Landform',
	'TVSeason'                              => 'CreativeWorkSeason',
	'ProductCollection'                     => 'Product',
	'VideoObjectSnapshot'                   => 'VideoObject',
	'MusicRecording'                        => 'CreativeWork',
	'3DModel'                               => 'MediaObject',
	'SchoolDistrict'                        => 'AdministrativeArea',
	'AggregateOffer'                        => 'Offer',
	'Distillery'                            => 'FoodEstablishment',
	'BroadcastFrequencySpecification'       => 'Intangible',
	'Manuscript'                            => 'CreativeWork',
	'GovernmentPermit'                      => 'Permit',
	'GolfCourse'                            => 'SportsActivityLocation',
	'EmploymentAgency'                      => 'LocalBusiness',
	'PaymentCard'                           => 'FinancialProduct',
	'UserTweets'                            => 'UserInteraction',
	'QAPage'                                => 'WebPage',
	'ParkingFacility'                       => 'CivicStructure',
	'HowToSection'                          => 'CreativeWork',
	'CampingPitch'                          => 'Accommodation',
	'MapCategoryType'                       => 'Enumeration',
	'TextObject'                            => 'MediaObject',
	'Map'                                   => 'CreativeWork',
	'SiteNavigationElement'                 => 'WebPageElement',
	'OnlineStore'                           => 'OnlineBusiness',
	'AssignAction'                          => 'AllocateAction',
	'FastFoodRestaurant'                    => 'FoodEstablishment',
	'QuantitativeValueDistribution'         => 'StructuredValue',
	'NGO'                                   => 'Organization',
	'RealEstateListing'                     => 'WebPage',
	'DigitalDocumentPermission'             => 'Intangible',
	'SomeProducts'                          => 'Product',
	'DiscoverAction'                        => 'FindAction',
	'ScholarlyArticle'                      => 'Article',
	'TaxiReservation'                       => 'Reservation',
	'Event'                                 => 'Thing',
	'RuntimePlatform'                       => 'SoftwareApplication',
	'Pharmacy'                              => 'MedicalOrganization',
	'AdministrativeArea'                    => 'Place',
	'Patient'                               => 'MedicalAudience',
	'Permit'                                => 'Intangible',
	'TattooParlor'                          => 'HealthAndBeautyBusiness',
	'PlayAction'                            => 'Action',
	'Protein'                               => 'BioChemEntity',
	'MotorizedBicycle'                      => 'Vehicle',
	'MedicalIndication'                     => 'MedicalEntity',
	'BusinessAudience'                      => 'Audience',
	'Guide'                                 => 'CreativeWork',
	'TheaterGroup'                          => 'PerformingGroup',
	'Playground'                            => 'CivicStructure',
	'Apartment'                             => 'Accommodation',
	'Course'                                => 'LearningResource',
	'CheckAction'                           => 'FindAction',
	'Quotation'                             => 'CreativeWork',
	'Taxon'                                 => 'Thing',
	'AchieveAction'                         => 'Action',
	'ShortStory'                            => 'CreativeWork',
	'WPHeader'                              => 'WebPageElement',
	'MedicalSignOrSymptom'                  => 'MedicalCondition',
	'Audience'                              => 'Intangible',
	'MusicRelease'                          => 'MusicPlaylist',
	'PaymentService'                        => 'FinancialProduct',
	'Episode'                               => 'CreativeWork',
	'PhysiciansOffice'                      => 'Physician',
	'AutoRepair'                            => 'AutomotiveBusiness',
	'GardenStore'                           => 'Store',
	'SocialMediaPosting'                    => 'Article',
	'TVClip'                                => 'Clip',
	'MediaReviewItem'                       => 'CreativeWork',
	'AmpStory'                              => 'CreativeWork',
	'ResetPasswordAction'                   => 'ControlAction',
	'PlanAction'                            => 'OrganizeAction',
	'Place'                                 => 'Thing',
	'BedDetails'                            => 'Intangible',
	'MediaGallery'                          => 'CollectionPage',
	'WarrantyPromise'                       => 'fibo-fnd-agr-ctr:MutualContractualAgreement',
	'Demand'                                => 'Intangible',
	'MedicalConditionStage'                 => 'MedicalIntangible',
	'PublicationVolume'                     => 'CreativeWork',
	'ImageObjectSnapshot'                   => 'ImageObject',
	'GovernmentOrganization'                => 'Organization',
	'Person'                                => 'Thing',
	'PeopleAudience'                        => 'Audience',
	'Integer'                               => 'Number',
	'PerformanceRole'                       => 'Role',
	'SoftwareApplication'                   => 'CreativeWork',
	'MenuSection'                           => 'CreativeWork',
	'Occupation'                            => 'Intangible',
	'FurnitureStore'                        => 'Store',
	'ReserveAction'                         => 'PlanAction',
	'MedicalAudienceType'                   => 'MedicalEnumeration',
	'DrugClass'                             => 'MedicalEntity',
	'WebPage'                               => 'CreativeWork',
	'MedicalObservationalStudy'             => 'MedicalStudy',
	'BusTrip'                               => 'Trip',
	'MerchantReturnEnumeration'             => 'Enumeration',
	'Organization'                          => 'Thing',
	'InfectiousDisease'                     => 'MedicalCondition',
	'Product'                               => 'Thing',
	'ContactPointOption'                    => 'Enumeration',
	'RentAction'                            => 'TradeAction',
	'TouristDestination'                    => 'Place',
	'DigitalDocument'                       => 'CreativeWork',
	'PreventionIndication'                  => 'MedicalIndication',
	'AppendAction'                          => 'InsertAction',
	'BookStore'                             => 'Store',
	'BloodTest'                             => 'MedicalTest',
	'PhysicalActivity'                      => 'LifestyleModification',
	'SuperficialAnatomy'                    => 'MedicalEntity',
	'Comment'                               => 'CreativeWork',
	'GeoShape'                              => 'StructuredValue',
	'GeoCoordinates'                        => 'StructuredValue',
	'Hackathon'                             => 'Event',
	'HowToStep'                             => 'CreativeWork',
	'Winery'                                => 'FoodEstablishment',
	'PaymentMethodType'                     => 'Enumeration',
	'MedicalStudy'                          => 'MedicalEntity',
	'Photograph'                            => 'CreativeWork',
	'FoodEstablishmentReservation'          => 'Reservation',
	'Language'                              => 'Intangible',
	'FundingScheme'                         => 'Organization',
	'Artery'                                => 'Vessel',
	'FundingAgency'                         => 'Project',
	'MusicComposition'                      => 'CreativeWork',
	'InvestmentOrDeposit'                   => 'FinancialProduct',
	'PriceSpecification'                    => 'StructuredValue',
	'PublicSwimmingPool'                    => 'SportsActivityLocation',
	'Error'                                 => 'InstantaneousEvent',
	'GameServerStatus'                      => 'StatusEnumeration',
	'CollegeOrUniversity'                   => 'EducationalOrganization',
	'ItemListOrderType'                     => 'Enumeration',
	'Corporation'                           => 'Organization',
	'OfferForPurchase'                      => 'Offer',
	'LegalValueLevel'                       => 'Enumeration',
	'DrugStrength'                          => 'MedicalIntangible',
	'Order'                                 => 'Intangible',
	'MedicalTestPanel'                      => 'MedicalTest',
	'ComicCoverArt'                         => 'ComicStory',
	'OpeningHoursSpecification'             => 'StructuredValue',
	'BuddhistTemple'                        => 'PlaceOfWorship',
	'BedAndBreakfast'                       => 'LodgingBusiness',
	'DrugLegalStatus'                       => 'MedicalIntangible',
	'SeekToAction'                          => 'Action',
	'FloorPlan'                             => 'Intangible',
	'SizeSpecification'                     => 'QualitativeValue',
	'Courthouse'                            => 'GovernmentBuilding',
	'VirtualLocation'                       => 'Intangible',
	'RadioSeries'                           => 'CreativeWorkSeries',
	'PaintAction'                           => 'CreateAction',
	'DrugCost'                              => 'MedicalEntity',
	'MediaObject'                           => 'CreativeWork',
	'Painting'                              => 'CreativeWork',
	'DefinedRegion'                         => 'Place',
	'MedicineSystem'                        => 'MedicalEnumeration',
	'ReplaceAction'                         => 'UpdateAction',
	'HealthPlanNetwork'                     => 'Intangible',
	'City'                                  => 'AdministrativeArea',
	'ApplyAction'                           => 'OrganizeAction',
	'SpreadsheetDigitalDocument'            => 'DigitalDocument',
	'SportsOrganization'                    => 'Organization',
	'MoneyTransfer'                         => 'TransferAction',
	'Car'                                   => 'Vehicle',
	'MedicalIntangible'                     => 'MedicalEntity',
	'DryCleaningOrLaundry'                  => 'LocalBusiness',
	'AuthenticateAction'                    => 'ControlAction',
	'ControlAction'                         => 'Action',
	'Recipe'                                => 'HowTo',
	'BookmarkAction'                        => 'OrganizeAction',
	'InsuranceAgency'                       => 'FinancialService',
	'TakeAction'                            => 'TransferAction',
	'SubwayStation'                         => 'CivicStructure',
	'PoliticalParty'                        => 'Organization',
	'RadioClip'                             => 'Clip',
	'TouristInformationCenter'              => 'LocalBusiness',
	'SeaBodyOfWater'                        => 'BodyOfWater',
	'Service'                               => 'Intangible',
	'OnlineBusiness'                        => 'Organization',
	'CivicStructure'                        => 'Place',
	'Duration'                              => 'Quantity',
	'Grant'                                 => 'Intangible',
	'LegalForceStatus'                      => 'StatusEnumeration',
	'HealthPlanFormulary'                   => 'Intangible',
	'ProductGroup'                          => 'cmns-cls:Classifier',
	'PoliceStation'                         => 'CivicStructure',
	'SportsTeam'                            => 'SportsOrganization',
	'PlayGameAction'                        => 'ConsumeAction',
	'ShippingDeliveryTime'                  => 'StructuredValue',
	'ContactPage'                           => 'WebPage',
	'DanceGroup'                            => 'PerformingGroup',
	'Sculpture'                             => 'CreativeWork',
	'RecyclingCenter'                       => 'LocalBusiness',
	'LocalBusiness'                         => 'Place',
	'SuspendAction'                         => 'ControlAction',
	'MediaSubscription'                     => 'Intangible',
	'NutritionInformation'                  => 'StructuredValue',
	'SportsActivityLocation'                => 'LocalBusiness',
	'Intangible'                            => 'Thing',
	'MedicalStudyStatus'                    => 'MedicalEnumeration',
	'Resort'                                => 'LodgingBusiness',
	'NLNonprofitType'                       => 'NonprofitType',
	'Atlas'                                 => 'CreativeWork',
	'SportsClub'                            => 'SportsActivityLocation',
	'MediaEnumeration'                      => 'Enumeration',
	'PriceTypeEnumeration'                  => 'Enumeration',
	'ReturnFeesEnumeration'                 => 'Enumeration',
	'UnitPriceSpecification'                => 'PriceSpecification',
	'RadioSeason'                           => 'CreativeWorkSeason',
	'ReturnAction'                          => 'TransferAction',
	'HealthAndBeautyBusiness'               => 'LocalBusiness',
	'OfferShippingDetails'                  => 'StructuredValue',
	'PresentationDigitalDocument'           => 'DigitalDocument',
	'Drawing'                               => 'CreativeWork',
	'BefriendAction'                        => 'InteractAction',
	'AgreeAction'                           => 'ReactAction',
	'RoofingContractor'                     => 'HomeAndConstructionBusiness',
	'OceanBodyOfWater'                      => 'BodyOfWater',
	'RiverBodyOfWater'                      => 'BodyOfWater',
	'MedicalScholarlyArticle'               => 'ScholarlyArticle',
	'ConfirmAction'                         => 'InformAction',
	'TVSeries'                              => 'CreativeWork',
	'GasStation'                            => 'AutomotiveBusiness',
	'WantAction'                            => 'ReactAction',
	'WPSideBar'                             => 'WebPageElement',
	'Library'                               => 'LocalBusiness',
	'TrainStation'                          => 'CivicStructure',
	'PerformAction'                         => 'PlayAction',
	'Class'                                 => 'Intangible',
	'AboutPage'                             => 'WebPage',
	'MathSolver'                            => 'CreativeWork',
	'EndorseAction'                         => 'ReactAction',
	'PrependAction'                         => 'InsertAction',
	'FilmAction'                            => 'CreateAction',
	'SolveMathAction'                       => 'Action',
	'EducationEvent'                        => 'Event',
	'ArriveAction'                          => 'MoveAction',
	'EmployeeRole'                          => 'OrganizationRole',
	'ExchangeRateSpecification'             => 'StructuredValue',
	'BusStop'                               => 'CivicStructure',
	'SoftwareSourceCode'                    => 'CreativeWork',
	'EmployerAggregateRating'               => 'AggregateRating',
	'EducationalOccupationalProgram'        => 'Intangible',
	'IncentiveQualifiedExpenseType'         => 'Enumeration',
	'Seat'                                  => 'Intangible',
	'LocationFeatureSpecification'          => 'PropertyValue',
	'AnimalShelter'                         => 'LocalBusiness',
	'MerchantReturnPolicySeasonalOverride'  => 'Intangible',
	'UserComments'                          => 'UserInteraction',
	'Volcano'                               => 'Landform',
	'InteractAction'                        => 'Action',
	'LearningResource'                      => 'CreativeWork',
	'Hospital'                              => 'CivicStructure',
	'Book'                                  => 'CreativeWork',
	'BuyAction'                             => 'TradeAction',
	'PriceComponentTypeEnumeration'         => 'Enumeration',
	'ShippingConditions'                    => 'StructuredValue',
	'HealthInsurancePlan'                   => 'Intangible',
	'BroadcastEvent'                        => 'PublicationEvent',
	'LoginAction'                           => 'ControlAction',
	'QuantitativeValue'                     => 'StructuredValue',
	'ReportedDoseSchedule'                  => 'DoseSchedule',
	'WPFooter'                              => 'WebPageElement',
	'CancelAction'                          => 'PlanAction',
	'CatholicChurch'                        => 'Church',
	'LoanOrCredit'                          => 'FinancialProduct',
	'PaymentStatusType'                     => 'StatusEnumeration',
	'OnDemandEvent'                         => 'PublicationEvent',
	'SequentialArt'                         => 'VisualArtwork',
	'SearchRescueOrganization'              => 'Organization',
	'EntertainmentBusiness'                 => 'LocalBusiness',
	'MenuItem'                              => 'Intangible',
	'TireShop'                              => 'Store',
	'Drug'                                  => 'Substance',
	'ExerciseAction'                        => 'PlayAction',
	'MonetaryGrant'                         => 'Grant',
	'BrokerageAccount'                      => 'InvestmentOrDeposit',
	'BowlingAlley'                          => 'SportsActivityLocation',
	'EventVenue'                            => 'CivicStructure',
	'DiagnosticProcedure'                   => 'MedicalProcedure',
	'HealthPlanCostSharingSpecification'    => 'Intangible',
	'TravelAction'                          => 'MoveAction',
	'MedicalObservationalStudyDesign'       => 'MedicalEnumeration',
	'ReservationStatusType'                 => 'StatusEnumeration',
	'Taxi'                                  => 'Service',
	'Airport'                               => 'CivicStructure',
	'DeactivateAction'                      => 'ControlAction',
	'CookAction'                            => 'CreateAction',
	'MovieSeries'                           => 'CreativeWorkSeries',
	'Observation'                           => 'Intangible',
	'ClothingStore'                         => 'Store',
	'FMRadioChannel'                        => 'RadioChannel',
	'ChemicalSubstance'                     => 'BioChemEntity',
	'USNonprofitType'                       => 'NonprofitType',
	'ComicIssue'                            => 'PublicationIssue',
	'Reservoir'                             => 'BodyOfWater',
	'CategoryCode'                          => 'DefinedTerm',
	'TextDigitalDocument'                   => 'DigitalDocument',
	'GenderType'                            => 'Enumeration',
	'APIReference'                          => 'TechArticle',
	'AutoBodyShop'                          => 'AutomotiveBusiness',
	'EnergyStarEnergyEfficiencyEnumeration' => 'EnergyEfficiencyEnumeration',
	'Quiz'                                  => 'LearningResource',
	'Embassy'                               => 'GovernmentBuilding',
	'Vein'                                  => 'Vessel',
	'RadioEpisode'                          => 'Episode',
	'ProfilePage'                           => 'WebPage',
	'Legislation'                           => 'CreativeWork',
	'VacationRental'                        => 'LodgingBusiness',
	'HotelRoom'                             => 'Room',
	'AcceptAction'                          => 'AllocateAction',
	'DeliveryEvent'                         => 'Event',
	'ListItem'                              => 'Intangible',
	'Joint'                                 => 'AnatomicalStructure',
	'DeleteAction'                          => 'UpdateAction',
	'ActionStatusType'                      => 'StatusEnumeration',
	'ConferenceEvent'                       => 'Event',
	'ConvenienceStore'                      => 'Store',
	'Flight'                                => 'Trip',
	'ScreeningEvent'                        => 'Event',
	'Game'                                  => 'CreativeWork',
	'ScheduleAction'                        => 'PlanAction',
	'MiddleSchool'                          => 'EducationalOrganization',
	'MedicalImagingTechnique'               => 'MedicalEnumeration',
	'ReadAction'                            => 'ConsumeAction',
	'CurrencyConversionService'             => 'FinancialProduct',
	'DrawAction'                            => 'CreateAction',
	'MensClothingStore'                     => 'Store',
	'ShareAction'                           => 'CommunicateAction',
	'MedicalSign'                           => 'MedicalSignOrSymptom',
	'Cemetery'                              => 'CivicStructure',
	'LakeBodyOfWater'                       => 'BodyOfWater',
	'Locksmith'                             => 'HomeAndConstructionBusiness',
	'CollectionPage'                        => 'WebPage',
	'ServicePeriod'                         => 'StructuredValue',
	'OrderAction'                           => 'TradeAction',
	'ComedyEvent'                           => 'Event',
	'CoverArt'                              => 'VisualArtwork',
	'Chapter'                               => 'CreativeWork',
	'PerformingArtsEvent'                   => 'Event',
	'RsvpResponseType'                      => 'Enumeration',
	'EndorsementRating'                     => 'Rating',
	'LifestyleModification'                 => 'MedicalEntity',
	'NonprofitType'                         => 'Enumeration',
	'LegislationObject'                     => 'MediaObject',
	'MedicalWebPage'                        => 'WebPage',
	'OfferItemCondition'                    => 'Enumeration',
	'PostalCodeRangeSpecification'          => 'StructuredValue',
	'HowTo'                                 => 'CreativeWork',
	'TaxiService'                           => 'Service',
	'SocialEvent'                           => 'Event',
	'BusinessEvent'                         => 'Event',
	'DiagnosticLab'                         => 'MedicalOrganization',
	'BedType'                               => 'QualitativeValue',
	'GiveAction'                            => 'TransferAction',
	'EnergyEfficiencyEnumeration'           => 'Enumeration',
	'TreatmentIndication'                   => 'MedicalIndication',
	'FireStation'                           => 'CivicStructure',
	'AmusementPark'                         => 'EntertainmentBusiness',
	'DeliveryChargeSpecification'           => 'PriceSpecification',
	'ListenAction'                          => 'ConsumeAction',
	'TravelAgency'                          => 'LocalBusiness',
	'BoatTerminal'                          => 'CivicStructure',
	'BookSeries'                            => 'CreativeWorkSeries',
	'MovingCompany'                         => 'HomeAndConstructionBusiness',
	'ComputerStore'                         => 'Store',
	'EnergyConsumptionDetails'              => 'Intangible',
	'HyperToc'                              => 'CreativeWork',
	'ComicStory'                            => 'CreativeWork',
	'LiveBlogPosting'                       => 'BlogPosting',
	'MedicalEntity'                         => 'Thing',
	'Table'                                 => 'WebPageElement',
	'SingleFamilyResidence'                 => 'House',
	'CommentAction'                         => 'CommunicateAction',
	'UserPageVisits'                        => 'UserInteraction',
	'AggregateRating'                       => 'Rating',
	'ItemAvailability'                      => 'Enumeration',
	'TelevisionStation'                     => 'LocalBusiness',
	'MedicalGuidelineRecommendation'        => 'MedicalGuideline',
	'ItemList'                              => 'Intangible',
	'LymphaticVessel'                       => 'Vessel',
	'PublicationIssue'                      => 'CreativeWork',
	'CertificationStatusEnumeration'        => 'Enumeration',
	'UpdateAction'                          => 'Action',
	'House'                                 => 'Accommodation',
	'MeasurementTypeEnumeration'            => 'Enumeration',
	'SpeakableSpecification'                => 'Intangible',
	'NightClub'                             => 'EntertainmentBusiness',
	'ExhibitionEvent'                       => 'Event',
	'NoteDigitalDocument'                   => 'DigitalDocument',
	'AutoWash'                              => 'AutomotiveBusiness',
	'RegisterAction'                        => 'InteractAction',
	'DefenceEstablishment'                  => 'GovernmentBuilding',
	'MedicalTrial'                          => 'MedicalStudy',
	'GameServer'                            => 'Intangible',
	'IncentiveStatus'                       => 'Enumeration',
	'CreativeWork'                          => 'Thing',
	'Bone'                                  => 'AnatomicalStructure',
	'SubscribeAction'                       => 'InteractAction',
	'QualitativeValue'                      => 'Enumeration',
	'DataDownload'                          => 'MediaObject',
	'PaymentMethod'                         => 'Intangible',
	'DiscussionForumPosting'                => 'SocialMediaPosting',
	'InviteAction'                          => 'CommunicateAction',
	'OrganizationRole'                      => 'Role',
	'DDxElement'                            => 'MedicalIntangible',
	'Ligament'                              => 'AnatomicalStructure',
	'ComicSeries'                           => 'Periodical',
	'Store'                                 => 'LocalBusiness',
	'EmployerReview'                        => 'Review',
	'GatedResidenceCommunity'               => 'Residence',
	'BusReservation'                        => 'Reservation',
	'Season'                                => 'CreativeWork',
	'EventSeries'                           => 'Event',
	'BroadcastService'                      => 'Service',
	'AllocateAction'                        => 'OrganizeAction',
	'SpecialAnnouncement'                   => 'CreativeWork',
	'MedicalGuideline'                      => 'MedicalEntity',
	'Plumber'                               => 'HomeAndConstructionBusiness',
	'Cooperative'                           => 'Organization',
	'Consortium'                            => 'Organization',
	'BrainStructure'                        => 'AnatomicalStructure',
	'Series'                                => 'Intangible',
	'RVPark'                                => 'CivicStructure',
	'RadioStation'                          => 'LocalBusiness',
	'MedicalRiskScore'                      => 'MedicalRiskEstimator',
	'TaxiStand'                             => 'CivicStructure',
	'FinancialProduct'                      => 'Service',
	'AddAction'                             => 'UpdateAction',
	'StructuredValue'                       => 'Intangible',
	'MemberProgramTier'                     => 'Intangible',
	'TypeAndQuantityNode'                   => 'StructuredValue',
	'MortgageLoan'                          => 'LoanOrCredit',
	'Airline'                               => 'Organization',
	'MedicalAudience'                       => 'Audience',
	'Reservation'                           => 'Intangible',
	'JobPosting'                            => 'Intangible',
	'DrugPrescriptionStatus'                => 'MedicalEnumeration',
	'ReactAction'                           => 'AssessAction',
	'WebApplication'                        => 'SoftwareApplication',
	'WorkBasedProgram'                      => 'EducationalOccupationalProgram',
	'SkiResort'                             => 'SportsActivityLocation',
	'BreadcrumbList'                        => 'ItemList',
	'SelfStorage'                           => 'LocalBusiness',
	'PodcastSeries'                         => 'CreativeWorkSeries',
	'AudioObject'                           => 'MediaObject',
	'ProductModel'                          => 'Product',
	'MedicalCondition'                      => 'MedicalEntity',
	'EventAttendanceModeEnumeration'        => 'Enumeration',
	'IndividualProduct'                     => 'Product',
	'IceCreamShop'                          => 'FoodEstablishment',
	'VisualArtwork'                         => 'CreativeWork',
	'Florist'                               => 'Store',
	'LodgingBusiness'                       => 'LocalBusiness',
	'DigitalPlatformEnumeration'            => 'Enumeration',
	'FinancialService'                      => 'LocalBusiness',
	'FlightReservation'                     => 'Reservation',
	'Movie'                                 => 'CreativeWork',
	'Researcher'                            => 'Audience',
	'DefinedTerm'                           => 'Intangible',
	'Code'                                  => 'CreativeWork',
	'Beach'                                 => 'CivicStructure',
	'MovieClip'                             => 'Clip',
	'OnlineMarketplace'                     => 'OnlineStore',
	'ShippingService'                       => 'StructuredValue',
	'Question'                              => 'Comment',
	'HowToTool'                             => 'HowToItem',
	'PerformingArtsTheater'                 => 'CivicStructure',
	'CovidTestingFacility'                  => 'MedicalClinic',
	'NewsMediaOrganization'                 => 'Organization',
	'PreOrderAction'                        => 'TradeAction',
	'CafeOrCoffeeShop'                      => 'FoodEstablishment',
	'URL'                                   => 'Text',
	'AutomatedTeller'                       => 'FinancialService',
	'InternetCafe'                          => 'LocalBusiness',
	'Action'                                => 'Thing',
	'PetStore'                              => 'Store',
	'InstantaneousEvent'                    => 'StructuredValue',
	'OfficeEquipmentStore'                  => 'Store',
	'XPathType'                             => 'Text',
	'DeliveryMethod'                        => 'Enumeration',
	'Motel'                                 => 'LodgingBusiness',
	'OccupationalExperienceRequirements'    => 'Intangible',
	'AssessAction'                          => 'Action',
	'MoveAction'                            => 'Action',
	'EmergencyService'                      => 'LocalBusiness',
	'BioChemEntity'                         => 'Thing',
	'PublicToilet'                          => 'CivicStructure',
	'SteeringPositionValue'                 => 'QualitativeValue',
	'AuthorizeAction'                       => 'AllocateAction',
	'TradeAction'                           => 'Action',
	'BroadcastChannel'                      => 'Intangible',
	'Trip'                                  => 'Intangible',
	'TieAction'                             => 'AchieveAction',
	'GamePlayMode'                          => 'Enumeration',
	'DisagreeAction'                        => 'ReactAction',
	'Enumeration'                           => 'Intangible',
	'Collection'                            => 'CreativeWork',
	'ReturnMethodEnumeration'               => 'Enumeration',
	'AutoPartsStore'                        => 'Store',
	'ArtGallery'                            => 'EntertainmentBusiness',
	'OrderItem'                             => 'StructuredValue',
	'EducationalOccupationalCredential'     => 'CreativeWork',
	'UserBlocks'                            => 'UserInteraction',
	'NewsArticle'                           => 'Article',
	'MediaReview'                           => 'Review',
	'RadioBroadcastService'                 => 'BroadcastService',
	'UseAction'                             => 'ConsumeAction',
	'SurgicalProcedure'                     => 'MedicalProcedure',
	'GovernmentService'                     => 'Service',
	'Physician'                             => 'MedicalOrganization',
	'Optician'                              => 'MedicalBusiness',
	'SheetMusic'                            => 'CreativeWork',
	'CreativeWorkSeries'                    => 'Series',
	'LiquorStore'                           => 'Store',
	'ChooseAction'                          => 'AssessAction',
	'RestrictedDiet'                        => 'Enumeration',
	'Project'                               => 'Organization',
	'HealthTopicContent'                    => 'WebContent',
	'Bakery'                                => 'FoodEstablishment',
	'Answer'                                => 'Comment',
	'ShippingRateSettings'                  => 'StructuredValue',
	'ItemPage'                              => 'WebPage',
	'ChildCare'                             => 'LocalBusiness',
	'CssSelectorType'                       => 'Text',
	'SizeSystemEnumeration'                 => 'Enumeration',
	'Bridge'                                => 'CivicStructure',
	'EducationalOrganization'               => 'Organization',
	'BusStation'                            => 'CivicStructure',
	'RejectAction'                          => 'AllocateAction',
	'Aquarium'                              => 'CivicStructure',
	'AdvertiserContentArticle'              => 'Article',
	'CompoundPriceSpecification'            => 'PriceSpecification',
	'TrainTrip'                             => 'Trip',
	'DepartAction'                          => 'MoveAction',
	'ProgramMembership'                     => 'Intangible',
	'Brewery'                               => 'FoodEstablishment',
	'Ticket'                                => 'Intangible',
	'UserInteraction'                       => 'Event',
	'HousePainter'                          => 'HomeAndConstructionBusiness',
	'Report'                                => 'Article',
	'DataFeed'                              => 'Dataset',
	'PlaceOfWorship'                        => 'CivicStructure',
	'Notary'                                => 'LegalService',
	'WebSite'                               => 'CreativeWork',
	'LibrarySystem'                         => 'Organization',
	'CreativeWorkSeason'                    => 'CreativeWork',
	'IncentiveType'                         => 'Enumeration',
	'AutomotiveBusiness'                    => 'LocalBusiness',
	'Vessel'                                => 'AnatomicalStructure',
	'DonateAction'                          => 'TransferAction',
	'LoseAction'                            => 'AchieveAction',
	'OrganizeAction'                        => 'Action',
	'PayAction'                             => 'TradeAction',
	'WearableMeasurementTypeEnumeration'    => 'MeasurementTypeEnumeration',
	'PodcastEpisode'                        => 'Episode',
	'Energy'                                => 'Quantity',
	'Campground'                            => 'CivicStructure',
	'Schedule'                              => 'Intangible',
	'Hotel'                                 => 'LodgingBusiness',
	'FinancialIncentive'                    => 'Intangible',
	'Claim'                                 => 'CreativeWork',
	'ParentAudience'                        => 'PeopleAudience',
	'Clip'                                  => 'CreativeWork',
	'HowToItem'                             => 'ListItem',
	'HomeAndConstructionBusiness'           => 'LocalBusiness',
	'InformAction'                          => 'CommunicateAction',
	'CityHall'                              => 'GovernmentBuilding',
	'VideoGallery'                          => 'MediaGallery',
	'MusicVideoObject'                      => 'MediaObject',
	'TierBenefitEnumeration'                => 'Enumeration',
	'BikeStore'                             => 'Store',
	'MemberProgram'                         => 'Intangible',
	'CorrectionComment'                     => 'Comment',
	'TrainReservation'                      => 'Reservation',
	'MusicReleaseFormatType'                => 'Enumeration',
	'MusicVenue'                            => 'CivicStructure',
	'LendAction'                            => 'TransferAction',
	'MusicAlbum'                            => 'MusicPlaylist',
	'CreditCard'                            => 'LoanOrCredit',
	'Vehicle'                               => 'Product',
	'HyperTocEntry'                         => 'CreativeWork',
	'Newspaper'                             => 'Periodical',
	'MedicalOrganization'                   => 'Organization',
	'Accommodation'                         => 'Place',
	'MedicalTrialDesign'                    => 'MedicalEnumeration',
	'PalliativeProcedure'                   => 'MedicalTherapy',
	'AlignmentObject'                       => 'Intangible',
	'DepartmentStore'                       => 'Store',
	'WebPageElement'                        => 'CreativeWork',
	'MusicAlbumProductionType'              => 'Enumeration',
	'WebAPI'                                => 'Service',
	'DislikeAction'                         => 'ReactAction',
	'SportsEvent'                           => 'Event',
	'AutoRental'                            => 'AutomotiveBusiness',
	'Electrician'                           => 'HomeAndConstructionBusiness',
	'Mosque'                                => 'PlaceOfWorship',
	'MedicalProcedureType'                  => 'MedicalEnumeration',
	'RealEstateAgent'                       => 'LocalBusiness',
	'ImageObject'                           => 'MediaObject',
	'Offer'                                 => 'Intangible',
	'MotorcycleRepair'                      => 'AutomotiveBusiness',
	'MedicalEnumeration'                    => 'Enumeration',
	'HowToSupply'                           => 'HowToItem',
	'HairSalon'                             => 'HealthAndBeautyBusiness',
	'CategoryCodeSet'                       => 'DefinedTermSet',
	'ArchiveComponent'                      => 'CreativeWork',
	'Waterfall'                             => 'BodyOfWater',
	'LegislativeBuilding'                   => 'GovernmentBuilding',
	'SatiricalArticle'                      => 'Article',
	'ViewAction'                            => 'ConsumeAction',
	'EUEnergyEfficiencyEnumeration'         => 'EnergyEfficiencyEnumeration',
	'FollowAction'                          => 'InteractAction',
	'AnatomicalStructure'                   => 'MedicalEntity',
	'TransferAction'                        => 'Action',
	'PawnShop'                              => 'Store',
	'AskAction'                             => 'CommunicateAction',
	'ImagingTest'                           => 'MedicalTest',
	'AdultEntertainment'                    => 'EntertainmentBusiness',
	'GeospatialGeometry'                    => 'Intangible',
	'ReviewAction'                          => 'AssessAction',
	'WebContent'                            => 'CreativeWork',
	'Barcode'                               => 'ImageObject',
	'ReceiveAction'                         => 'TransferAction',
	'Attorney'                              => 'LegalService',
	'ElementarySchool'                      => 'EducationalOrganization',
	'ExercisePlan'                          => 'PhysicalActivity',
	'DrinkAction'                           => 'ConsumeAction',
	'WPAdBlock'                             => 'WebPageElement',
	'MonetaryAmountDistribution'            => 'QuantitativeValueDistribution',
	'ReportageNewsArticle'                  => 'NewsArticle',
	'StatisticalPopulation'                 => 'Intangible',
	'SizeGroupEnumeration'                  => 'Enumeration',
	'Canal'                                 => 'BodyOfWater',
	'ShoppingCenter'                        => 'LocalBusiness',
	'BoardingPolicyType'                    => 'Enumeration',
	'PropertyValue'                         => 'StructuredValue',
	'HVACBusiness'                          => 'HomeAndConstructionBusiness',
	'DaySpa'                                => 'HealthAndBeautyBusiness',
	'StatisticalVariable'                   => 'ConstraintNode',
	'InstallAction'                         => 'ConsumeAction',
	'DataType'                              => 'rdfs:Class',
	'UserPlusOnes'                          => 'UserInteraction',
	'Property'                              => 'Intangible',
	'DietarySupplement'                     => 'Substance',
	'School'                                => 'EducationalOrganization',
	'WearableSizeSystemEnumeration'         => 'SizeSystemEnumeration',
	'PodcastSeason'                         => 'CreativeWorkSeason',
	'Float'                                 => 'Number',
	'Museum'                                => 'CivicStructure',
	'Country'                               => 'cmns-ge:GeopoliticalEntity',
	'MovieRentalStore'                      => 'Store',
	'MaximumDoseSchedule'                   => 'DoseSchedule',
	'Play'                                  => 'CreativeWork',
	'PublicationEvent'                      => 'Event',
	'HomeGoodsStore'                        => 'Store',
	'Message'                               => 'CreativeWork',
	'InteractionCounter'                    => 'StructuredValue',
	'EmailMessage'                          => 'Message',
	'BusOrCoach'                            => 'Vehicle',
	'OccupationalTherapy'                   => 'MedicalTherapy',
	'ClaimReview'                           => 'Review',
	'MovieTheater'                          => 'CivicStructure',
	'CommunicateAction'                     => 'InteractAction',
	'MusicGroup'                            => 'PerformingGroup',
	'MusicAlbumReleaseType'                 => 'Enumeration',
	'MedicalTherapy'                        => 'TherapeuticProcedure',
	'MerchantReturnPolicy'                  => 'Intangible',
	'BodyMeasurementTypeEnumeration'        => 'MeasurementTypeEnumeration',
	'ComputerLanguage'                      => 'Intangible',
	'FulfillmentTypeEnumeration'            => 'Enumeration',
	'InsertAction'                          => 'AddAction',
	'VoteAction'                            => 'ChooseAction',
	'CableOrSatelliteService'               => 'Service',
	'PerformingGroup'                       => 'Organization',
	'GameAvailabilityEnumeration'           => 'Enumeration',
	'BankAccount'                           => 'FinancialProduct',
	'RadiationTherapy'                      => 'MedicalTherapy',
	'Audiobook'                             => 'AudioObject',
	'WinAction'                             => 'AchieveAction',
	'MotorcycleDealer'                      => 'AutomotiveBusiness',
	'SendAction'                            => 'TransferAction',
	'Menu'                                  => 'CreativeWork',
	'VideoObject'                           => 'MediaObject',
	'ApartmentComplex'                      => 'Residence',
	'ResumeAction'                          => 'ControlAction',
	'Crematorium'                           => 'CivicStructure',
	'UnRegisterAction'                      => 'InteractAction',
	'MedicalBusiness'                       => 'LocalBusiness',
	'Dataset'                               => 'CreativeWork',
	'Gene'                                  => 'BioChemEntity',
	'IgnoreAction'                          => 'AssessAction',
	'Restaurant'                            => 'FoodEstablishment',
	'EatAction'                             => 'ConsumeAction',
	'BoatTrip'                              => 'Trip',
	'CheckoutPage'                          => 'WebPage',
	'OutletStore'                           => 'Store',
	'Residence'                             => 'Place',
	'Specialty'                             => 'Enumeration',
	'Landform'                              => 'Place',
	'ComedyClub'                            => 'EntertainmentBusiness',
	'ArchiveOrganization'                   => 'LocalBusiness',
	'DrugCostCategory'                      => 'MedicalEnumeration',
	'Hostel'                                => 'LodgingBusiness',
	'AnatomicalSystem'                      => 'MedicalEntity',
	'Motorcycle'                            => 'Vehicle',
	'ParcelDelivery'                        => 'Intangible',
	'BlogPosting'                           => 'SocialMediaPosting',
	'BookFormatType'                        => 'Enumeration',
	'EventStatusType'                       => 'StatusEnumeration',
	'BeautySalon'                           => 'HealthAndBeautyBusiness',
	'DataCatalog'                           => 'CreativeWork',
	'MedicalDevice'                         => 'MedicalEntity',
	'OrderStatus'                           => 'StatusEnumeration',
	'ProfessionalService'                   => 'LocalBusiness',
	'HighSchool'                            => 'EducationalOrganization',
	'PhotographAction'                      => 'CreateAction',
	'TVEpisode'                             => 'Episode',
	'ConstraintNode'                        => 'Intangible',
	'RefundTypeEnumeration'                 => 'Enumeration',
	'ApprovedIndication'                    => 'MedicalIndication',
	'ReplyAction'                           => 'CommunicateAction',
	'ServiceChannel'                        => 'Intangible',
	'DoseSchedule'                          => 'MedicalIntangible',
	'InfectiousAgentClass'                  => 'MedicalEnumeration',
	'BankOrCreditUnion'                     => 'FinancialService',
	'Festival'                              => 'Event',
	'LegalService'                          => 'LocalBusiness',
	'VideoGame'                             => 'SoftwareApplication',
	'MedicalDevicePurpose'                  => 'MedicalEnumeration',
	'RentalCarReservation'                  => 'Reservation',
	'Role'                                  => 'Intangible',
	'PhysicalActivityCategory'              => 'Enumeration',
	'Mountain'                              => 'Landform',
	'UserReview'                            => 'Review',
	'State'                                 => 'AdministrativeArea',
	'Synagogue'                             => 'PlaceOfWorship',
	'LiteraryEvent'                         => 'Event',
	'GeoCircle'                             => 'GeoShape',
	'Poster'                                => 'CreativeWork',
	'Quantity'                              => 'Intangible',
	'Mass'                                  => 'Quantity',
	'EducationalAudience'                   => 'Audience',
	'MolecularEntity'                       => 'BioChemEntity',
	'Invoice'                               => 'fibo-fnd-arr-doc:LegalDocument',
	'WriteAction'                           => 'CreateAction',
	'GeneralContractor'                     => 'HomeAndConstructionBusiness',
	'CarUsageType'                          => 'Enumeration',
	'VideoGameClip'                         => 'Clip',
	'DownloadAction'                        => 'TransferAction',
	'ImageGallery'                          => 'MediaGallery',
	'UserCheckins'                          => 'UserInteraction',
	'EngineSpecification'                   => 'StructuredValue',
	'PronounceableText'                     => 'Text',
	'DigitalDocumentPermissionType'         => 'Enumeration',
	'Suite'                                 => 'Accommodation',
	'TelevisionChannel'                     => 'BroadcastChannel',
	'ResearchOrganization'                  => 'Organization',
	'CheckInAction'                         => 'CommunicateAction',
	'MedicalCause'                          => 'MedicalEntity',
	'BusinessFunction'                      => 'Enumeration',
	'SellAction'                            => 'TradeAction',
	'Blog'                                  => 'CreativeWork',
	'SaleEvent'                             => 'Event',
	'DriveWheelConfigurationValue'          => 'QualitativeValue',
	'PostOffice'                            => 'GovernmentOffice',
	'CDCPMDRecord'                          => 'StructuredValue',
	'MedicalRiskCalculator'                 => 'MedicalRiskEstimator',
	'HowToTip'                              => 'CreativeWork',
	'Recommendation'                        => 'Review',
	'MedicalCode'                           => 'MedicalIntangible',
	'LinkRole'                              => 'Role',
	'PurchaseType'                          => 'Enumeration',
	'WorkersUnion'                          => 'Organization',
	'SportingGoodsStore'                    => 'Store',
	'BusinessEntityType'                    => 'Enumeration',
	'AutoDealer'                            => 'AutomotiveBusiness',
	'ChildrensEvent'                        => 'Event',
	'MedicalProcedure'                      => 'MedicalEntity',
	'PhysicalExam'                          => 'MedicalEnumeration',
	'ReservationPackage'                    => 'Reservation',
	'PhysicalTherapy'                       => 'MedicalTherapy',
	'TechArticle'                           => 'Article',
	'Brand'                                 => 'Intangible',
	'Park'                                  => 'CivicStructure',
	'Preschool'                             => 'EducationalOrganization',
	'MedicalRiskEstimator'                  => 'MedicalEntity',
	'OfferForLease'                         => 'Offer',
	'CreateAction'                          => 'Action',
	'MarryAction'                           => 'InteractAction',
	'InvestmentFund'                        => 'InvestmentOrDeposit',
	'RsvpAction'                            => 'InformAction',
	'VeterinaryCare'                        => 'MedicalOrganization',
	'Casino'                                => 'EntertainmentBusiness',
	'EventReservation'                      => 'Reservation',
	'GovernmentOffice'                      => 'LocalBusiness',
	'HobbyShop'                             => 'Store',
	'RecommendedDoseSchedule'               => 'DoseSchedule',
	'UserPlays'                             => 'UserInteraction',
	'ShoeStore'                             => 'Store',
	'HealthAspectEnumeration'               => 'Enumeration',
	'TennisComplex'                         => 'SportsActivityLocation',
	'PsychologicalTreatment'                => 'TherapeuticProcedure',
	'RadioChannel'                          => 'BroadcastChannel',
	'Dentist'                               => 'LocalBusiness',
	'Review'                                => 'CreativeWork',
	'MedicalEvidenceLevel'                  => 'MedicalEnumeration',
	'TherapeuticProcedure'                  => 'MedicalProcedure',
	'ResearchProject'                       => 'Project',
	'CourseInstance'                        => 'Event',
	'MedicalSpecialty'                      => 'Specialty',
	'BackgroundNewsArticle'                 => 'NewsArticle',
	'MonetaryAmount'                        => 'StructuredValue',
	'MobilePhoneStore'                      => 'Store',
	'ActivateAction'                        => 'ControlAction',
	'CheckOutAction'                        => 'CommunicateAction',
	'HowToDirection'                        => 'CreativeWork',
	'FoodService'                           => 'Service',
	'Syllabus'                              => 'LearningResource',
	'GovernmentBenefitsType'                => 'Enumeration',
	'StadiumOrArena'                        => 'CivicStructure',
	'UserDownloads'                         => 'UserInteraction',
	'MusicPlaylist'                         => 'CreativeWork',
	'BodyOfWater'                           => 'Landform',
	'SearchAction'                          => 'Action',
	'MusicEvent'                            => 'Event',
	'ReturnLabelSourceEnumeration'          => 'Enumeration',
	'Substance'                             => 'MedicalEntity',
	'OpinionNewsArticle'                    => 'NewsArticle',
	'TouristTrip'                           => 'Trip',
	'ContactPoint'                          => 'StructuredValue',
	'MobileApplication'                     => 'SoftwareApplication',
	'Statement'                             => 'CreativeWork',
	'RepaymentSpecification'                => 'StructuredValue',
	'ReviewNewsArticle'                     => 'NewsArticle',
	'MedicalContraindication'               => 'MedicalEntity',
	'WarrantyScope'                         => 'Enumeration',
	'DefinedTermSet'                        => 'CreativeWork',
	'DatedMoneySpecification'               => 'StructuredValue',
	'MediaManipulationRatingEnumeration'    => 'Enumeration',
	'NailSalon'                             => 'HealthAndBeautyBusiness',
	'LandmarksOrHistoricalBuildings'        => 'Place',
	'PaymentChargeSpecification'            => 'PriceSpecification',
	'MedicalGuidelineContraindication'      => 'MedicalGuideline',
	'Rating'                                => 'Intangible',
	'Pond'                                  => 'BodyOfWater',
	'LodgingReservation'                    => 'Reservation',
	'TipAction'                             => 'TradeAction',
	'OwnershipInfo'                         => 'StructuredValue',
	'PathologyTest'                         => 'MedicalTest',
	'HardwareStore'                         => 'Store',
	'MedicalClinic'                         => 'MedicalOrganization',
	'ExerciseGym'                           => 'SportsActivityLocation',
	'VisualArtsEvent'                       => 'Event',
	'MeasurementMethodEnum'                 => 'Enumeration',
	'LikeAction'                            => 'ReactAction',
	'HinduTemple'                           => 'PlaceOfWorship',
	'VitalSign'                             => 'MedicalSign',
	'UKNonprofitType'                       => 'NonprofitType',
	'ElectronicsStore'                      => 'Store',
	'UserLikes'                             => 'UserInteraction',
	'PropertyValueSpecification'            => 'Intangible',
	'DanceEvent'                            => 'Event',
	'FindAction'                            => 'Action',
	'HealthClub'                            => 'HealthAndBeautyBusiness',
	'DepositAccount'                        => 'BankAccount',
	'AskPublicNewsArticle'                  => 'NewsArticle',
	'QuoteAction'                           => 'TradeAction',
	'AMRadioChannel'                        => 'RadioChannel',
	'AccountingService'                     => 'FinancialService',
	'BarOrPub'                              => 'FoodEstablishment',
	'SearchResultsPage'                     => 'WebPage',
	'Church'                                => 'PlaceOfWorship',
	'VideoGameSeries'                       => 'CreativeWorkSeries',
	'AdultOrientedEnumeration'              => 'Enumeration',
	'Periodical'                            => 'CreativeWorkSeries',
	'IndividualPhysician'                   => 'Physician',
	'WearAction'                            => 'UseAction',
	'FoodEvent'                             => 'Event',
	'MedicalTest'                           => 'MedicalEntity',
	'PostalAddress'                         => 'ContactPoint',
	'MedicalSymptom'                        => 'MedicalSignOrSymptom',
	'FAQPage'                               => 'WebPage',
	'TrackAction'                           => 'FindAction',
	'GovernmentBuilding'                    => 'CivicStructure',
	'Zoo'                                   => 'CivicStructure',
	'ConsumeAction'                         => 'Action',
	'AudioObjectSnapshot'                   => 'AudioObject',
	'DayOfWeek'                             => 'Enumeration',
	'OfferCatalog'                          => 'ItemList',
	'Distance'                              => 'Quantity',
	'BorrowAction'                          => 'TransferAction',
	'Article'                               => 'CreativeWork',
	'ActionAccessSpecification'             => 'Intangible',
	'TouristAttraction'                     => 'Place',
	'GroceryStore'                          => 'Store',
	'EntryPoint'                            => 'Intangible',
	'Thesis'                                => 'CreativeWork',
	'StatusEnumeration'                     => 'Enumeration',
	'Nerve'                                 => 'AnatomicalStructure',
	'MeetingRoom'                           => 'Room',
	'DataFeedItem'                          => 'Intangible',
	'MusicStore'                            => 'Store',
	'ToyStore'                              => 'Store',
	'Muscle'                                => 'AnatomicalStructure',
	'DrugPregnancyCategory'                 => 'MedicalEnumeration',
	'OperatingSystem'                       => 'SoftwareApplication',
	'JoinAction'                            => 'InteractAction',
);
