@charset "UTF-8";
@use './blocks';
/*--------------------------------------------------------------------------------------------
*
*	Vars
*
*--------------------------------------------------------------------------------------------*/
/* colors */
/* acf-field */
/* responsive */
/*--------------------------------------------------------------------------------------------
*
*	ACF 6 ↓
*
*--------------------------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------------------------
*
*  Mixins
*
*--------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------
*
*  Repeater
*
*---------------------------------------------------------------------------------------------*/
.acf-repeater {
  /* table */
  /* row handle (add/remove) */
  /* add in spacer to th (force correct width) */
  /* row */
  /* sortable */
  /* layouts */
  /*
  	&.-row > table > tbody > tr:before,
  	&.-block > table > tbody > tr:before {
  		content: "";
  		display: table-row;
  		height: 2px;
  		background: #f00;
  	}
  */
  /* empty */
  /* collapsed */
  /* collapsed (block layout) */
  /* collapsed (table layout) */
}
.acf-repeater > table {
  margin: 0 0 8px;
  background: #F9F9F9;
}
.acf-repeater > table > tbody tr.acf-divider:not(:first-child) > td {
  border-top: 10px solid #EAECF0;
}
.acf-repeater .acf-row-handle {
  width: 16px;
  text-align: center !important;
  vertical-align: middle !important;
  position: relative;
  /* icons */
  /* .order */
  /* remove */
}
.acf-repeater .acf-row-handle .acf-order-input-wrap {
  width: 45px;
}
.acf-repeater .acf-row-handle .acf-order-input::-webkit-outer-spin-button,
.acf-repeater .acf-row-handle .acf-order-input::-webkit-inner-spin-button {
  -webkit-appearance: none;
  margin: 0;
}
.acf-repeater .acf-row-handle .acf-order-input {
  -moz-appearance: textfield;
  text-align: center;
}
.acf-repeater .acf-row-handle .acf-icon {
  display: none;
  position: absolute;
  top: 0;
  margin: -8px 0 0 -2px;
  /* minus icon */
}
.acf-repeater .acf-row-handle .acf-icon.-minus {
  top: 50%;
  /* ie fix */
}
body.browser-msie .acf-repeater .acf-row-handle .acf-icon.-minus {
  top: 25px;
}
.acf-repeater .acf-row-handle.order {
  background: #f4f4f4;
  cursor: move;
  color: #aaa;
  text-shadow: #fff 0 1px 0;
}
.acf-repeater .acf-row-handle.order:hover {
  color: #666;
}
.acf-repeater .acf-row-handle.order + td {
  border-left-color: #DFDFDF;
}
.acf-repeater .acf-row-handle.pagination {
  cursor: auto;
}
.acf-repeater .acf-row-handle.remove {
  background: #F9F9F9;
  border-left-color: #DFDFDF;
}
.acf-repeater th.acf-row-handle:before {
  content: "";
  width: 16px;
  display: block;
  height: 1px;
}
.acf-repeater .acf-row {
  /* hide clone */
  /* hover */
}
.acf-repeater .acf-row.acf-clone {
  display: none !important;
}
.acf-repeater .acf-row:hover, .acf-repeater .acf-row.-hover {
  /* icons */
}
.acf-repeater .acf-row:hover > .acf-row-handle .acf-icon, .acf-repeater .acf-row.-hover > .acf-row-handle .acf-icon {
  display: block;
}
.acf-repeater .acf-row:hover > .acf-row-handle .acf-icon.show-on-shift, .acf-repeater .acf-row.-hover > .acf-row-handle .acf-icon.show-on-shift {
  display: none;
}
body.acf-keydown-shift .acf-repeater .acf-row:hover > .acf-row-handle .acf-icon.show-on-shift, body.acf-keydown-shift .acf-repeater .acf-row.-hover > .acf-row-handle .acf-icon.show-on-shift {
  display: block;
}
body.acf-keydown-shift .acf-repeater .acf-row:hover > .acf-row-handle .acf-icon.hide-on-shift, body.acf-keydown-shift .acf-repeater .acf-row.-hover > .acf-row-handle .acf-icon.hide-on-shift {
  display: none;
}
.acf-repeater > table > tbody > tr.ui-sortable-helper {
  box-shadow: 0 1px 5px rgba(0, 0, 0, 0.2);
}
.acf-repeater > table > tbody > tr.ui-sortable-placeholder {
  visibility: visible !important;
}
.acf-repeater > table > tbody > tr.ui-sortable-placeholder td {
  background: #F9F9F9;
}
.acf-repeater.-row > table > tbody > tr > td, .acf-repeater.-block > table > tbody > tr > td {
  border-top-color: #E1E1E1;
}
.acf-repeater.-empty > table > thead > tr > th {
  border-bottom: 0 none;
}
.acf-repeater.-empty.-row > table, .acf-repeater.-empty.-block > table {
  display: none;
}
.acf-repeater .acf-row.-collapsed > .acf-field {
  display: none !important;
}
.acf-repeater .acf-row.-collapsed > td.acf-field.-collapsed-target {
  display: table-cell !important;
}
.acf-repeater .acf-row.-collapsed > .acf-fields > * {
  display: none !important;
}
.acf-repeater .acf-row.-collapsed > .acf-fields > .acf-field.-collapsed-target {
  display: block !important;
}
.acf-repeater .acf-row.-collapsed > .acf-fields > .acf-field.-collapsed-target[data-width] {
  float: none !important;
  width: auto !important;
}
.acf-repeater.-table .acf-row.-collapsed .acf-field.-collapsed-target {
  border-left-color: #dfdfdf;
}
.acf-repeater.-max .acf-icon[data-event=add-row] {
  display: none !important;
}
.acf-repeater > .acf-actions .acf-button {
  float: right;
  pointer-events: auto !important;
}
.acf-repeater > .acf-actions .acf-tablenav {
  float: right;
  margin-right: 20px;
}
.acf-repeater > .acf-actions .acf-tablenav .current-page {
  width: auto !important;
}

/*---------------------------------------------------------------------------------------------
*
*  Flexible Content
*
*---------------------------------------------------------------------------------------------*/
.acf-flexible-content {
  position: relative;
  container-name: flexible-content;
  container-type: inline-size;
}
.acf-flexible-content > .clones {
  display: none;
}
.acf-flexible-content > .values {
  margin: 0 0 8px;
}
.acf-flexible-content > .values > .ui-sortable-placeholder {
  visibility: visible !important;
  border: 1px dashed #b4b9be;
  box-shadow: none;
  background: transparent;
}
.acf-flexible-content .layout {
  position: relative;
  margin: 20px 0 0;
  background: #fff;
  border: 1px solid #ccd0d4;
}
.acf-flexible-content .layout:first-child {
  margin-top: 0;
}

.acf-flexible-content .layout[data-enabled="0"]>.acf-fc-layout-actions-wrap .acf-layout-disabled {
  display: inline-flex
}

.acf-flexible-content .layout[data-renamed="1"] .acf-fc-layout-actions-wrap .acf-fc-layout-original-title {
  display: flex
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap {
  display: flex;
  justify-content: space-between;
  align-items: center;
  min-height: 48px;
  border-bottom: #ccd0d4 solid 1px;
  padding: 0 8px 0 12px;
  background: #f9f9f9
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-handle {
  display: flex;
  align-items: center;
  cursor: move;
  color: #444;
  font-size: 13px;
  font-weight: 500;
  line-height: 1.4em;
  flex-grow: 1;
  gap: 8px
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-layout-disabled {
  display: none;
  font-size: 12px;
  font-weight: normal;
  line-height: 16px;
  border-radius: 2px;
  background-color: #e0e0e0;
  color: #101828;
  padding: 4px 8px;
  margin-left: 4px
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-layout-disabled:before {
  content: "";
  width: 16px;
  height: 16px;
  margin-right: 4px;
  background: #101828;
  -webkit-mask-image: url("../../../images/icons/icon-hidden.svg");
  mask-image: url("../../../images/icons/icon-hidden.svg")
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-original-title {
  display: none;
  font-weight: 400;
  color: rgba(68, 68, 68, .5)
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-order,
.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-draggable-icon {
  display: flex;
  justify-content: center;
  width: 32px;
  height: 20px;
  border: 1px solid #e0e0e0;
  border-radius: 10px;
  box-sizing: border-box;
  line-height: 18px;
  background: #f0f0f0;
  font-size: 12px;
  color: #757575
}

html[dir=rtl] .acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-order,
html[dir=rtl] .acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-draggable-icon {
  float: right;
  margin-right: 0;
  margin-left: 5px;
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-order+.acf-fc-layout-draggable-icon {
  display: none;
  border: 1px solid #2f2f2f;
  background: #2f2f2f
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-order+.acf-fc-layout-draggable-icon:before {
  content: "";
  width: 7px;
  height: 11px;
  margin: auto;
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  background: #fff;
  vertical-align: middle;
  -webkit-mask-image: url("../../../images/icons/icon-draggable.svg");
  mask-image: url("../../../images/icons/icon-draggable.svg")
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls {
  display: flex;
  align-items: center;
  gap: 5px
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .disabled .acf-icon {
    background: #ccc !important
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-plus-alt,
.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-duplicate-alt,
.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-trash-alt,
.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-more-actions {
  visibility: hidden;
  background: #101828
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-collapse {
  border: none;
  color: #101828
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-icon.-collapse:hover {
  background: none;
  color: #101828
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-layout-collapse {
  display: flex;
  align-items: center;
  align-content: center;
  margin-left: 8px;
  padding-left: 4px;
  border-left: 1px solid #d9d9d9
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls a:focus {
  border-radius: 2px
}

html[dir=rtl] .acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls {
  right: auto;
  left: 9px
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap:hover .acf-fc-layout-order {
  display: none
}

.acf-flexible-content .layout .acf-fc-layout-actions-wrap:hover .acf-fc-layout-draggable-icon {
  display: flex
}

.acf-flexible-content .layout>.acf-fields,
.acf-flexible-content .layout>.acf-table {
  border: 1px solid rgba(0, 0, 0, 0);
  border-top: none
}

.acf-flexible-content .layout.active-layout {
  border-color: rgba(0, 0, 0, 0)
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap {
  background: var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9));
  border: none
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-draggable-icon {
  border-color: #fff;
  background: #fff
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-draggable-icon:before {
  background: var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9))
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-handle {
  color: #fff
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-handle .acf-fc-layout-order {
  background: rgba(240, 240, 240, .2);
  border-color: rgba(224, 224, 224, .34);
  color: #fff
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-handle .acf-fc-layout-original-title {
  color: hsla(0, 0%, 100%, .5)
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .disabled .acf-icon {
    background: hsla(0, 0%, 100%, .3)
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-plus-alt,
.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-duplicate-alt,
.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-trash-alt,
.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-more-actions {
  background: #fff;
  visibility: visible
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-collapse {
  color: #fff
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .-collapse:hover {
  color: #fff
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-layout-collapse {
  border-left-color: hsla(0, 0%, 100%, .2)
}

.acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap .acf-fc-layout-controls a:focus {
  box-shadow: 0 0 0 1px #fff
}

.acf-flexible-content .layout.active-layout>.acf-fields,
.acf-flexible-content .layout.active-layout>.acf-table {
  background: rgba(56, 88, 233, .04);
  border: 1px solid rgba(56, 88, 233, .2)
}

.acf-flexible-content .layout.is-selected {
  border-color: #7e8993;
}
.acf-flexible-content .layout.is-selected .acf-fc-layout-handle {
  border-color: #7e8993;
}
.acf-flexible-content .layout:hover .acf-fc-layout-controls .acf-icon.-plus-alt,
.acf-flexible-content .layout:hover .acf-fc-layout-controls .acf-icon.-duplicate-alt,
.acf-flexible-content .layout:hover .acf-fc-layout-controls .acf-icon.-trash-alt,
.acf-flexible-content .layout:hover .acf-fc-layout-controls .acf-icon.-more-actions,
.acf-flexible-content .layout.-hover .acf-fc-layout-controls .acf-icon.-plus-alt,
.acf-flexible-content .layout.-hover .acf-fc-layout-controls .acf-icon.-duplicate-alt,
.acf-flexible-content .layout.-hover .acf-fc-layout-controls .acf-icon.-trash-alt,
.acf-flexible-content .layout.-hover .acf-fc-layout-controls .acf-icon.-more-actions {
  visibility: visible
}
.acf-flexible-content .layout.-collapsed>.acf-fc-layout-actions-wrap {
  border-bottom-width: 0
}
.acf-flexible-content .layout.-collapsed > .acf-fields,
.acf-flexible-content .layout.-collapsed > .acf-table {
  display: none;
}
.acf-flexible-content .layout > .acf-table {
  box-shadow: none;
  box-sizing: border-box;
}
.acf-flexible-content .layout > .acf-table > tbody > tr {
  background: #fff;
}
.acf-flexible-content .layout > .acf-table > thead > tr > th {
  background: #F9F9F9;
}
.acf-flexible-content .no-value-message {
  padding: 19px;
  border: #ccc dashed 2px;
  text-align: center;
  display: none;
}
.acf-flexible-content.-empty > .no-value-message {
  display: block;
}


.acf-flexible-content.-empty .acf-fc-top-actions {
  display: none !important
}

.acf-flexible-content>.acf-actions {
  display: flex;
  justify-content: flex-end
}

.acf-flexible-content>.acf-actions.acf-fc-top-actions {
  gap: 20px;
  margin-bottom: 15px
}

.acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-separator {
  display: inline-block;
  width: 1px;
  height: 40px;
  background: #d9d9d9
}

.acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-btn-clear {
  color: #0783be !important;
  padding: 0
}

.acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-btn-clear:hover {
  text-decoration: underline
}

.acf-flexible-content>.acf-actions .acf-button {
  display: inline-flex;
  align-items: center
}

@container flexible-content (max-width: 400px) {
    .acf-flexible-content>.acf-actions.acf-fc-top-actions {
        flex-wrap: wrap;
        gap: 10px
    }

    .acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-separator {
        display: none
    }

    .acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-btn-clear {
        flex: 1 1 auto;
        text-align: center;
        justify-content: center
    }

    .acf-flexible-content>.acf-actions.acf-fc-top-actions .acf-button {
        flex: 1 1 100%;
        justify-content: center;
        width: 100%
    }
}

#acf-popup .acf-rename-layout-popup .inner .acf-field:first-child {
  margin-top: 0
}

#acf-popup .acf-rename-layout-popup .inner .acf-field .acf-label {
  text-transform: uppercase;
  font-size: 11px
}

#acf-popup .acf-rename-layout-popup .inner .acf-field input[type=text] {
  height: 40px;
  border-radius: 0
}

#acf-popup .acf-rename-layout-popup .inner .acf-actions {
  padding-top: 10px
}

#acf-popup .acf-rename-layout-popup .inner .acf-actions .acf-reset-label {
  flex-grow: 1;
  padding-left: 0;
  padding-right: 0
}

#acf-popup .acf-rename-layout-popup .inner .acf-actions .acf-confirm {
  background: var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9)) !important
}

#acf-popup .acf-rename-layout-popup .inner .acf-actions .acf-confirm:hover {
  background: var(--wp-components-color-accent-darker-10, var(--wp-admin-theme-color-darker-10, #2145e6)) !important
}

.block-editor-page .acf-flexible-content>.acf-actions .acf-button {
  border-radius: 2px;
  height: 40px
}

.block-editor-page .acf-flexible-content>.acf-actions .acf-button.button-primary {
  background: var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9))
}

.block-editor-page .acf-flexible-content>.acf-actions .acf-button.button-primary:hover {
  background: var(--wp-components-color-accent-darker-10, var(--wp-admin-theme-color-darker-10, #2145e6))
}

body:not(.block-editor-page) .acf-flexible-content .acf-fc-top-actions {
  min-height: 30px
}

body:not(.block-editor-page) .acf-flexible-content .acf-fc-top-actions .acf-separator {
  height: 30px
}

body:not(.block-editor-page) .acf-flexible-content .acf-fc-top-actions .acf-btn {
  min-height: 30px
}

body:not(.block-editor-page) .acf-flexible-content .layout.active-layout>.acf-fc-layout-actions-wrap {
  background: #2271b1
}

body:not(.block-editor-page) .acf-flexible-content .layout.active-layout>.acf-fields,
body:not(.block-editor-page) .acf-flexible-content .layout.active-layout>.acf-table {
    background: rgba(34, 113, 177, .04)
}

.rtl .acf-flexible-content .layout .acf-fc-layout-actions-wrap {
  padding: 0 12px 0 0
}

.rtl .acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-layout-disabled:before {
  margin-right: 0;
  margin-left: 4px
}

.rtl .acf-flexible-content .layout .acf-fc-layout-actions-wrap .acf-fc-layout-controls .acf-layout-collapse {
  border-right: 1px solid #d9d9d9;
  border-left: none;
  padding: 0 4px 0 0
}

.rtl .acf-fc-popup.acf-more-layout-actions li a:before {
  margin-right: 0;
  margin-left: 5px
}

.acf-fc-popup {
  background: #fff;
  border: 1px solid #d0d5dd;
  padding: 2px 8px;
  z-index: 900001;
  min-width: 135px;
}

.acf-fc-popup:before {
  content: none
}

.acf-fc-popup ul {
  display: flex;
  flex-direction: column;
  list-style: none
}

.acf-fc-popup ul, .acf-fc-popup li {
  margin: 0;
  padding: 0;
}
.acf-fc-popup li {
  position: relative;
  float: none;
  white-space: nowrap;
  height: 40px;
  display: flex;
  align-items: center
}
.acf-fc-popup .badge {
  display: inline-block;
  border-radius: 8px;
  font-size: 9px;
  line-height: 15px;
  padding: 0 5px;
  background: #d54e21;
  text-align: center;
  color: #fff;
  vertical-align: top;
  margin: 2px 0 0 5px;
}
.acf-fc-popup a {
  color: #101828;
  width: 100%;
  display: block;
  text-decoration: none;
  position: relative;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}
.acf-fc-popup a:hover {
  color: #2271b1;
}
.acf-fc-popup a.disabled {
  color: #888;
  background: transparent;
}

.acf-fc-popup a:focus {
  box-shadow: 0 0 0 var(--wp-admin-border-width-focus) var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9));
  border-radius: 4px
}

.acf-fc-popup.acf-more-layout-actions {
  width: 212px
}

.acf-fc-popup.acf-more-layout-actions li a {
  width: 100%
}

.acf-fc-popup.acf-more-layout-actions li a:before {
  content: "";
  display: inline-block;
  width: 16px;
  height: 16px;
  -webkit-mask-repeat: no-repeat;
  mask-repeat: no-repeat;
  margin-right: 5px;
  background: #101828;
  vertical-align: middle;
  margin-top: -2px
}

.acf-fc-popup.acf-more-layout-actions li a:hover:before {
  background: #2271b1
}

.acf-fc-popup.acf-more-layout-actions li a.acf-rename-layout:before {
  -webkit-mask-image: url("../../../images/icons/icon-edit.svg");
  mask-image: url("../../../images/icons/icon-edit.svg")
}

.acf-fc-popup.acf-more-layout-actions li a.acf-toggle-layout:before {
  -webkit-mask-image: url("../../../images/icons/icon-hidden-alt.svg");
  mask-image: url("../../../images/icons/icon-hidden-alt.svg")
}

.acf-fc-popup.acf-more-layout-actions li a.acf-toggle-layout.enable {
  display: none
}

.acf-fc-popup.acf-more-layout-actions li a.acf-toggle-layout.enable:before {
  -webkit-mask-image: url("../../../images/icons/icon-visible.svg");
  mask-image: url("../../../images/icons/icon-visible.svg")
}

.acf-fc-popup.acf-more-layout-actions li a.acf-toggle-layout.disabled {
    pointer-events: none
}

.acf-fc-popup.acf-more-layout-actions li a.acf-toggle-layout.disabled:before {
    background: #888
}

.acf-fc-popup.acf-more-layout-actions.enable-layout .acf-toggle-layout.disable {
  display: none
}

.acf-fc-popup.acf-more-layout-actions.enable-layout .acf-toggle-layout.enable {
  display: block
}

body:not(.block-editor-page) .acf-more-layout-actions li a:focus {
  box-shadow: 0 0 0 2px #2271b1
}

/*---------------------------------------------------------------------------------------------
*
*  Galery
*
*---------------------------------------------------------------------------------------------*/
.acf-gallery {
  border: #ccd0d4 solid 1px;
  height: 400px;
  position: relative;
  /* main */
  /* attachments */
  /* attachment */
  /* toolbar */
  /* sidebar */
  /* side info */
  /* side data */
  /* column widths */
  /* resizable */
}
.acf-gallery .acf-gallery-main {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: #fff;
  z-index: 2;
}
.acf-gallery .acf-gallery-attachments {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 48px;
  left: 0;
  padding: 5px;
  overflow: auto;
  overflow-x: hidden;
}
.acf-gallery .acf-gallery-attachment {
  width: 25%;
  float: left;
  cursor: pointer;
  position: relative;
  /* hover */
  /* sortable */
  /* active */
  /* icon */
  /* rtl */
}
.acf-gallery .acf-gallery-attachment .margin {
  margin: 5px;
  border: #d5d9dd solid 1px;
  position: relative;
  overflow: hidden;
  background: #eee;
}
.acf-gallery .acf-gallery-attachment .margin:before {
  content: "";
  display: block;
  padding-top: 100%;
}
.acf-gallery .acf-gallery-attachment .thumbnail {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  transform: translate(50%, 50%);
}
html[dir=rtl] .acf-gallery .acf-gallery-attachment .thumbnail {
  transform: translate(-50%, 50%);
}
.acf-gallery .acf-gallery-attachment .thumbnail img {
  display: block;
  height: auto;
  max-height: 100%;
  width: auto;
  transform: translate(-50%, -50%);
}
html[dir=rtl] .acf-gallery .acf-gallery-attachment .thumbnail img {
  transform: translate(50%, -50%);
}
.acf-gallery .acf-gallery-attachment .filename {
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  padding: 5%;
  background: #F4F4F4;
  background: rgba(255, 255, 255, 0.8);
  border-top: #DFDFDF solid 1px;
  font-weight: bold;
  text-align: center;
  word-wrap: break-word;
  max-height: 90%;
  overflow: hidden;
}
.acf-gallery .acf-gallery-attachment .actions {
  position: absolute;
  top: 0;
  right: 0;
  display: none;
}
.acf-gallery .acf-gallery-attachment:hover .actions {
  display: block;
}
.acf-gallery .acf-gallery-attachment.ui-sortable-helper .margin {
  border: none;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.3);
}
.acf-gallery .acf-gallery-attachment.ui-sortable-placeholder .margin {
  background: #F1F1F1;
  border: none;
}
.acf-gallery .acf-gallery-attachment.ui-sortable-placeholder .margin * {
  display: none !important;
}
.acf-gallery .acf-gallery-attachment.active .margin {
  box-shadow: 0 0 0 1px #FFFFFF, 0 0 0 5px #0073aa;
}
.acf-gallery .acf-gallery-attachment.-icon .thumbnail img {
  transform: translate(-50%, -70%);
}
html[dir=rtl] .acf-gallery .acf-gallery-attachment {
  float: right;
}
.acf-gallery.sidebar-open {
  /* hide attachment actions when sidebar is open */
  /* allow sidebar to move over main for small widths (widget edit box) */
}
.acf-gallery.sidebar-open .acf-gallery-attachment .actions {
  display: none;
}
.acf-gallery.sidebar-open .acf-gallery-side {
  z-index: 2;
}
.acf-gallery .acf-gallery-toolbar {
  position: absolute;
  right: 0;
  bottom: 0;
  left: 0;
  padding: 10px;
  border-top: #d5d9dd solid 1px;
  background: #fff;
  min-height: 28px;
}
.acf-gallery .acf-gallery-toolbar .acf-hl li {
  line-height: 24px;
}
.acf-gallery .acf-gallery-toolbar .bulk-actions-select {
  width: auto;
  margin: 0 1px 0 0;
}
.acf-gallery .acf-gallery-side {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  width: 0;
  background: #F9F9F9;
  border-left: #ccd0d4 solid 1px;
  z-index: 1;
  overflow: hidden;
}
.acf-gallery .acf-gallery-side .acf-gallery-side-inner {
  position: absolute;
  top: 0;
  left: 0;
  bottom: 0;
  width: 349px;
}
.acf-gallery .acf-gallery-side-info {
  position: relative;
  width: 100%;
  padding: 10px;
  margin: -10px 0 15px -10px;
  background: #F1F1F1;
  border-bottom: #DFDFDF solid 1px;
}
.acf-gallery .acf-gallery-side-info:after {
  display: block;
  clear: both;
  content: "";
}
html[dir=rtl] .acf-gallery .acf-gallery-side-info {
  margin-left: 0;
  margin-right: -10px;
}
.acf-gallery .acf-gallery-side-info img {
  float: left;
  width: auto;
  max-width: 65px;
  max-height: 65px;
  margin: 0 10px 1px 0;
  background: #FFFFFF;
  padding: 3px;
  border: #ccd0d4 solid 1px;
  border-radius: 1px;
  /* rtl */
}
html[dir=rtl] .acf-gallery .acf-gallery-side-info img {
  float: right;
  margin: 0 0 0 10px;
}
.acf-gallery .acf-gallery-side-info p {
  font-size: 13px;
  line-height: 15px;
  margin: 3px 0;
  word-break: break-all;
  color: #666;
}
.acf-gallery .acf-gallery-side-info p strong {
  color: #000;
}
.acf-gallery .acf-gallery-side-info a {
  text-decoration: none;
}
.acf-gallery .acf-gallery-side-info a.acf-gallery-edit {
  color: #21759b;
}
.acf-gallery .acf-gallery-side-info a.acf-gallery-remove {
  color: #bc0b0b;
}
.acf-gallery .acf-gallery-side-info a:hover {
  text-decoration: underline;
}
.acf-gallery .acf-gallery-side-data {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 48px;
  left: 0;
  overflow: auto;
  overflow-x: inherit;
  padding: 10px;
}
.acf-gallery .acf-gallery-side-data .acf-label,
.acf-gallery .acf-gallery-side-data th.label {
  color: #666666;
  font-size: 12px;
  line-height: 25px;
  padding: 0 4px 8px 0 !important;
  width: auto !important;
  vertical-align: top;
}
html[dir=rtl] .acf-gallery .acf-gallery-side-data .acf-label,
html[dir=rtl] .acf-gallery .acf-gallery-side-data th.label {
  padding: 0 0 8px 4px !important;
}
.acf-gallery .acf-gallery-side-data .acf-label label,
.acf-gallery .acf-gallery-side-data th.label label {
  font-weight: normal;
}
.acf-gallery .acf-gallery-side-data .acf-input,
.acf-gallery .acf-gallery-side-data td.field {
  padding: 0 0 8px !important;
}
.acf-gallery .acf-gallery-side-data textarea {
  min-height: 0;
  height: 60px;
}
.acf-gallery .acf-gallery-side-data p.help {
  font-size: 12px;
}
.acf-gallery .acf-gallery-side-data p.help:hover {
  font-weight: normal;
}
.acf-gallery[data-columns="1"] .acf-gallery-attachment {
  width: 100%;
}
.acf-gallery[data-columns="2"] .acf-gallery-attachment {
  width: 50%;
}
.acf-gallery[data-columns="3"] .acf-gallery-attachment {
  width: 33.333%;
}
.acf-gallery[data-columns="4"] .acf-gallery-attachment {
  width: 25%;
}
.acf-gallery[data-columns="5"] .acf-gallery-attachment {
  width: 20%;
}
.acf-gallery[data-columns="6"] .acf-gallery-attachment {
  width: 16.666%;
}
.acf-gallery[data-columns="7"] .acf-gallery-attachment {
  width: 14.285%;
}
.acf-gallery[data-columns="8"] .acf-gallery-attachment {
  width: 12.5%;
}
.acf-gallery .ui-resizable-handle {
  display: block;
  position: absolute;
}
.acf-gallery .ui-resizable-s {
  bottom: -5px;
  cursor: ns-resize;
  height: 7px;
  left: 0;
  width: 100%;
}

/* media modal selected */
.acf-media-modal .attachment.acf-selected {
  box-shadow: 0 0 0 3px #fff inset, 0 0 0 7px #0073aa inset !important;
}
.acf-media-modal .attachment.acf-selected .check {
  display: none !important;
}
.acf-media-modal .attachment.acf-selected .thumbnail {
  opacity: 0.25 !important;
}
.acf-media-modal .attachment.acf-selected .attachment-preview:before {
  background: rgba(0, 0, 0, 0.15);
  z-index: 1;
  position: relative;
}

.acf-admin-single-options-page .select2-dropdown {
  border-color: #6BB5D8 !important;
  margin-top: -5px;
  overflow: hidden;
  box-shadow: 0px 1px 2px rgba(16, 24, 40, 0.1);
}
.acf-admin-single-options-page .select2-dropdown.select2-dropdown--above {
  margin-top: 0;
}
.acf-admin-single-options-page .select2-container--default .select2-results__option[aria-selected=true] {
  background-color: #F9FAFB !important;
  color: #667085;
}
.acf-admin-single-options-page .select2-container--default .select2-results__option[aria-selected=true]:hover {
  color: #399CCB;
}
.acf-admin-single-options-page .select2-container--default .select2-results__option--highlighted[aria-selected] {
  color: #fff !important;
  background-color: #0783BE !important;
}
.acf-admin-single-options-page .select2-dropdown .select2-results__option {
  margin-bottom: 0;
}

.acf-create-options-page-popup ~ .select2-container {
  z-index: 999999999;
}

/*-----------------------------------------------------------------------------
*
*	ACF Blocks
*
*----------------------------------------------------------------------------*/
.acf-block-component .components-placeholder {
  margin: 0;
}

.block-editor .acf-field.acf-error {
  background-color: rgba(255, 0, 0, 0.05);
}

.acf-block-component .acf-block-fields {
  background: #fff;
  text-align: left;
  font-size: 13px;
  line-height: 1.4em;
  color: #444;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
}
.acf-block-component .acf-block-fields.acf-empty-block-fields {
  border: 1px solid #1e1e1e;
  padding: 12px;
}
.components-panel .acf-block-component .acf-block-fields.acf-empty-block-fields {
  border: none;
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
}
html[dir=rtl] .acf-block-component .acf-block-fields {
  text-align: right;
}
.acf-block-component .acf-block-fields p {
  font-size: 13px;
  line-height: 1.5;
}

.acf-block-body .acf-block-fields:has(> .acf-error-message),
.acf-block-fields:has(> .acf-error-message) .acf-block-fields:has(> .acf-error-message) {
  border: none !important;
}
.acf-block-body .acf-error-message,
.acf-block-fields:has(> .acf-error-message) .acf-error-message {
  margin-top: 0;
  border: none;
}
.acf-block-body .acf-error-message .acf-notice-dismiss,
.acf-block-fields:has(> .acf-error-message) .acf-error-message .acf-notice-dismiss {
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  outline: unset;
}
.acf-block-body .acf-error-message .acf-icon.-cancel::before,
.acf-block-fields:has(> .acf-error-message) .acf-error-message .acf-icon.-cancel::before {
  margin: 0 !important;
}
.acf-block-body.acf-block-has-validation-error,
.acf-block-fields:has(> .acf-error-message).acf-block-has-validation-error {
  border: 2px solid #d94f4f;
}
.acf-block-body .acf-error .acf-input .acf-notice,
.acf-block-fields:has(> .acf-error-message) .acf-error .acf-input .acf-notice {
  background: none !important;
  border: none !important;
  display: flex !important;
  align-items: center !important;
  padding-left: 0;
}
.acf-block-body .acf-error .acf-input .acf-notice p,
.acf-block-fields:has(> .acf-error-message) .acf-error .acf-input .acf-notice p {
  margin: 0.5em 0 !important;
}
.acf-block-body .acf-error .acf-input .acf-notice::before,
.acf-block-fields:has(> .acf-error-message) .acf-error .acf-input .acf-notice::before {
  content: "";
  position: relative;
  top: 0;
  left: 0;
  font-size: 20px;
  background-image: url(../../../images/icons/icon-info-red.svg);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 69%;
  height: 26px !important;
  width: 26px !important;
  box-sizing: border-box;
}
.acf-block-body .acf-error .acf-label label,
.acf-block-fields:has(> .acf-error-message) .acf-error .acf-label label {
  color: #d94f4f;
}
.acf-block-body .acf-error .acf-input input,
.acf-block-fields:has(> .acf-error-message) .acf-error .acf-input input {
  border-color: #d94f4f;
}
.acf-block-body.acf-block-has-validation-error::before,
.acf-block-fields:has(> .acf-error-message).acf-block-has-validation-error::before {
  content: "";
  position: absolute;
  top: -2px;
  left: -32px;
  font-size: 20px;
  background-color: #d94f4f;
  background-image: url(../../../images/icons/icon-info-white.svg);
  background-repeat: no-repeat;
  background-position-x: center;
  background-position-y: 52%;
  background-size: 55%;
  height: 40px;
  width: 32px;
  box-sizing: border-box;
}
.acf-block-body .acf-block-validation-error,
.acf-block-fields:has(> .acf-error-message) .acf-block-validation-error {
  color: #d94f4f;
  display: flex;
  align-items: center;
}
.acf-block-body .acf-block-fields,
.acf-block-fields:has(> .acf-error-message) .acf-block-fields {
  border: #adb2ad solid 1px;
}
.acf-block-body .acf-block-fields .acf-tab-wrap .acf-tab-group,
.acf-block-fields:has(> .acf-error-message) .acf-block-fields .acf-tab-wrap .acf-tab-group {
  margin-left: 0;
  padding: 16px 20px 0;
}
.acf-block-body .acf-fields > .acf-field,
.acf-block-fields:has(> .acf-error-message) .acf-fields > .acf-field {
  padding: 16px 20px;
}
.acf-block-body .acf-fields > .acf-field.acf-accordion,
.acf-block-fields:has(> .acf-error-message) .acf-fields > .acf-field.acf-accordion {
  border-color: #adb2ad;
}
.acf-block-body .acf-fields > .acf-field.acf-accordion .acf-accordion-title,
.acf-block-fields:has(> .acf-error-message) .acf-fields > .acf-field.acf-accordion .acf-accordion-title {
  padding: 16px 20px;
}
.acf-block-body .acf-button,
.acf-block-body .acf-link a.button,
.acf-block-body .acf-add-checkbox,
.acf-block-fields:has(> .acf-error-message) .acf-button,
.acf-block-fields:has(> .acf-error-message) .acf-link a.button,
.acf-block-fields:has(> .acf-error-message) .acf-add-checkbox {
  color: #2271b1 !important;
  border-color: #2271b1 !important;
  background: #f6f7f7 !important;
  vertical-align: top;
}
.acf-block-body .acf-button.button-primary:hover,
.acf-block-body .acf-link a.button.button-primary:hover,
.acf-block-body .acf-add-checkbox.button-primary:hover,
.acf-block-fields:has(> .acf-error-message) .acf-button.button-primary:hover,
.acf-block-fields:has(> .acf-error-message) .acf-link a.button.button-primary:hover,
.acf-block-fields:has(> .acf-error-message) .acf-add-checkbox.button-primary:hover {
  color: white !important;
  background: #2271b1 !important;
}
.acf-block-body .acf-button:focus,
.acf-block-body .acf-link a.button:focus,
.acf-block-body .acf-add-checkbox:focus,
.acf-block-fields:has(> .acf-error-message) .acf-button:focus,
.acf-block-fields:has(> .acf-error-message) .acf-link a.button:focus,
.acf-block-fields:has(> .acf-error-message) .acf-add-checkbox:focus {
  outline: none !important;
  background: #f6f7f7 !important;
}
.acf-block-body .acf-button:hover,
.acf-block-body .acf-link a.button:hover,
.acf-block-body .acf-add-checkbox:hover,
.acf-block-fields:has(> .acf-error-message) .acf-button:hover,
.acf-block-fields:has(> .acf-error-message) .acf-link a.button:hover,
.acf-block-fields:has(> .acf-error-message) .acf-add-checkbox:hover {
  color: #0a4b78 !important;
}
.acf-block-body .acf-block-preview,
.acf-block-fields:has(> .acf-error-message) .acf-block-preview {
  min-height: 10px;
}

.acf-block-panel .acf-block-fields {
  border-top: #ddd solid 1px;
  border-bottom: #ddd solid 1px;
  min-height: 1px;
}
.acf-block-panel .acf-block-fields:empty {
  border-top: none;
}
.acf-block-panel .acf-block-fields .acf-tab-wrap {
  background: transparent;
}

.components-panel__body .acf-block-panel {
  margin: 16px -16px -16px;
}