<?php // phpcs:disable PEAR.NamingConventions.ValidClassName
/**
 * The former ACF Pro class file.
 *
 * Remains, for now, in case anything checks for the existence of this class.
 *
 * @package wordpress/secure-custom-fields
 */

if ( ! class_exists( 'acf_pro' ) ) :
	/**
	 * The main ACF PRO class.
	 */
	class acf_pro {
		/**
		 * Empty constructor.
		 */
		public function __construct() {
		}
	}
	// end class
endif;
