<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitb858699864578c66b2ddae4494f7a6e4
{
    public static $prefixLengthsPsr4 = array (
        'S' => 
        array (
            'SCF\\Site_Health\\' => 16,
            'SCF\\Meta\\' => 9,
            'SCF\\Forms\\' => 10,
            'SCF\\Fields\\FlexibleContent\\' => 27,
            'SCF\\Datastore\\' => 14,
            'SCF\\CLI\\' => 8,
            'SCF\\Blocks\\' => 11,
            'SCF\\AI\\' => 7,
        ),
        'J' => 
        array (
            'JsonSchema\\' => 11,
        )
    );

    public static $prefixDirsPsr4 = array (
        'SCF\\Site_Health\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src/Site_Health',
        ),
        'SCF\\Meta\\' => 
        array (
            0 => __DIR__ . '/../..' . '/includes/Meta',
        ),
        'SCF\\Forms\\' => 
        array (
            0 => __DIR__ . '/../..' . '/includes/forms',
        ),
        'SCF\\Fields\\FlexibleContent\\' => 
        array (
            0 => __DIR__ . '/../..' . '/includes/fields/FlexibleContent',
        ),
        'SCF\\Datastore\\' => 
        array (
            0 => __DIR__ . '/../..' . '/includes/Datastore',
        ),
        'SCF\\CLI\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src/CLI',
        ),
        'SCF\\Blocks\\' => 
        array (
            0 => __DIR__ . '/../..' . '/includes/Blocks',
        ),
        'SCF\\AI\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src/AI',
        ),
        'JsonSchema\\' => 
        array (
            0 => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema',
        )
    );

    public static $classMap = array (
        'JsonSchema\\Constraints\\BaseConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/BaseConstraint.php',
        'JsonSchema\\Constraints\\CollectionConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/CollectionConstraint.php',
        'JsonSchema\\Constraints\\Constraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Constraint.php',
        'JsonSchema\\Constraints\\ConstraintInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ConstraintInterface.php',
        'JsonSchema\\Constraints\\EnumConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/EnumConstraint.php',
        'JsonSchema\\Constraints\\Factory' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Factory.php',
        'JsonSchema\\Constraints\\FormatConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/FormatConstraint.php',
        'JsonSchema\\Constraints\\NumberConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/NumberConstraint.php',
        'JsonSchema\\Constraints\\ObjectConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ObjectConstraint.php',
        'JsonSchema\\Constraints\\SchemaConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/SchemaConstraint.php',
        'JsonSchema\\Constraints\\StringConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/StringConstraint.php',
        'JsonSchema\\Constraints\\TypeCheck\\LooseTypeCheck' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/LooseTypeCheck.php',
        'JsonSchema\\Constraints\\TypeCheck\\StrictTypeCheck' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/StrictTypeCheck.php',
        'JsonSchema\\Constraints\\TypeCheck\\TypeCheckInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/TypeCheckInterface.php',
        'JsonSchema\\Constraints\\TypeConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeConstraint.php',
        'JsonSchema\\Constraints\\UndefinedConstraint' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Constraints/UndefinedConstraint.php',
        'JsonSchema\\Entity\\JsonPointer' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Entity/JsonPointer.php',
        'JsonSchema\\Exception\\ExceptionInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/ExceptionInterface.php',
        'JsonSchema\\Exception\\InvalidArgumentException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidArgumentException.php',
        'JsonSchema\\Exception\\InvalidConfigException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidConfigException.php',
        'JsonSchema\\Exception\\InvalidSchemaException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaException.php',
        'JsonSchema\\Exception\\InvalidSchemaMediaTypeException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaMediaTypeException.php',
        'JsonSchema\\Exception\\InvalidSourceUriException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSourceUriException.php',
        'JsonSchema\\Exception\\JsonDecodingException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/JsonDecodingException.php',
        'JsonSchema\\Exception\\ResourceNotFoundException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/ResourceNotFoundException.php',
        'JsonSchema\\Exception\\RuntimeException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/RuntimeException.php',
        'JsonSchema\\Exception\\UnresolvableJsonPointerException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/UnresolvableJsonPointerException.php',
        'JsonSchema\\Exception\\UriResolverException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/UriResolverException.php',
        'JsonSchema\\Exception\\ValidationException' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Exception/ValidationException.php',
        'JsonSchema\\Iterator\\ObjectIterator' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Iterator/ObjectIterator.php',
        'JsonSchema\\Rfc3339' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Rfc3339.php',
        'JsonSchema\\SchemaStorage' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorage.php',
        'JsonSchema\\SchemaStorageInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorageInterface.php',
        'JsonSchema\\UriResolverInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/UriResolverInterface.php',
        'JsonSchema\\UriRetrieverInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/UriRetrieverInterface.php',
        'JsonSchema\\Uri\\Retrievers\\AbstractRetriever' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/AbstractRetriever.php',
        'JsonSchema\\Uri\\Retrievers\\Curl' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/Curl.php',
        'JsonSchema\\Uri\\Retrievers\\FileGetContents' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/FileGetContents.php',
        'JsonSchema\\Uri\\Retrievers\\PredefinedArray' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/PredefinedArray.php',
        'JsonSchema\\Uri\\Retrievers\\UriRetrieverInterface' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/UriRetrieverInterface.php',
        'JsonSchema\\Uri\\UriResolver' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriResolver.php',
        'JsonSchema\\Uri\\UriRetriever' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriRetriever.php',
        'JsonSchema\\Validator' => __DIR__ . '/..' . '/justinrainbow/json-schema/src/JsonSchema/Validator.php',
        'SCF\\AI\\AI' => __DIR__ . '/../..' . '/src/AI/AI.php',
        'SCF\\AI\\Abilities\\Abilities' => __DIR__ . '/../..' . '/src/AI/Abilities/Abilities.php',
        'SCF\\AI\\Abilities\\AbstractAbilityGroup' => __DIR__ . '/../..' . '/src/AI/Abilities/AbstractAbilityGroup.php',
        'SCF\\AI\\Abilities\\FieldGroup' => __DIR__ . '/../..' . '/src/AI/Abilities/FieldGroup.php',
        'SCF\\AI\\Abilities\\PostType' => __DIR__ . '/../..' . '/src/AI/Abilities/PostType.php',
        'SCF\\AI\\Abilities\\SCF_REST_Ability' => __DIR__ . '/../..' . '/src/AI/Abilities/SCF_REST_Ability.php',
        'SCF\\AI\\Abilities\\Taxonomy' => __DIR__ . '/../..' . '/src/AI/Abilities/Taxonomy.php',
        'SCF\\AI\\GEO\\FieldSettings' => __DIR__ . '/../..' . '/src/AI/GEO/FieldSettings.php',
        'SCF\\AI\\GEO\\GEO' => __DIR__ . '/../..' . '/src/AI/GEO/GEO.php',
        'SCF\\AI\\GEO\\Outputs\\Blocks' => __DIR__ . '/../..' . '/src/AI/GEO/Outputs/Blocks.php',
        'SCF\\AI\\GEO\\Outputs\\Posts' => __DIR__ . '/../..' . '/src/AI/GEO/Outputs/Posts.php',
        'SCF\\AI\\GEO\\Schema' => __DIR__ . '/../..' . '/src/AI/GEO/Schema.php',
        'SCF\\AI\\GEO\\SchemaData' => __DIR__ . '/../..' . '/src/AI/GEO/SchemaData.php',
        'SCF\\Blocks\\Bindings' => __DIR__ . '/../..' . '/includes/Blocks/Bindings.php',
        'SCF\\Blocks\\Bindings_Editor' => __DIR__ . '/../..' . '/includes/Blocks/Bindings_Editor.php',
        'SCF\\CLI\\CLI' => __DIR__ . '/../..' . '/src/CLI/CLI.php',
        'SCF\\CLI\\JsonCommand' => __DIR__ . '/../..' . '/src/CLI/JsonCommand.php',
        'SCF\\Datastore\\Check_Screen' => __DIR__ . '/../..' . '/includes/Datastore/Check_Screen.php',
        'SCF\\Datastore\\Localization' => __DIR__ . '/../..' . '/includes/Datastore/Localization.php',
        'SCF\\Datastore\\REST_Save' => __DIR__ . '/../..' . '/includes/Datastore/REST_Save.php',
        'SCF\\Datastore\\Revisions' => __DIR__ . '/../..' . '/includes/Datastore/Revisions.php',
        'SCF\\Fields\\FlexibleContent\\Layout' => __DIR__ . '/../..' . '/includes/fields/FlexibleContent/Layout.php',
        'SCF\\Fields\\FlexibleContent\\Render' => __DIR__ . '/../..' . '/includes/fields/FlexibleContent/Render.php',
        'SCF\\Forms\\WC_Order' => __DIR__ . '/../..' . '/includes/forms/WC_Order.php',
        'SCF\\Meta\\Comment' => __DIR__ . '/../..' . '/includes/Meta/Comment.php',
        'SCF\\Meta\\MetaLocation' => __DIR__ . '/../..' . '/includes/Meta/MetaLocation.php',
        'SCF\\Meta\\Option' => __DIR__ . '/../..' . '/includes/Meta/Option.php',
        'SCF\\Meta\\Post' => __DIR__ . '/../..' . '/includes/Meta/Post.php',
        'SCF\\Meta\\Term' => __DIR__ . '/../..' . '/includes/Meta/Term.php',
        'SCF\\Meta\\User' => __DIR__ . '/../..' . '/includes/Meta/User.php',
        'SCF\\Meta\\WooOrder' => __DIR__ . '/../..' . '/includes/Meta/WooOrder.php',
        'SCF\\Site_Health\\AI_Usage' => __DIR__ . '/../..' . '/src/Site_Health/AI_Usage.php',
        'SCF\\Site_Health\\Site_Health' => __DIR__ . '/../..' . '/src/Site_Health/Site_Health.php'
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitb858699864578c66b2ddae4494f7a6e4::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitb858699864578c66b2ddae4494f7a6e4::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitb858699864578c66b2ddae4494f7a6e4::$classMap;

        }, null, ClassLoader::class);
    }
}
